----------------------------------------------------------------------------------------------------
--   OCO Source Materials
--
--   Licensed Materials - Property of IBM
--
--   5724-C02
--
--   (C) Copyright IBM Corp. 2003  All Rights Reserved.
--
--   US Government Users Restricted Rights - Use, duplication or
--   disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
----------------------------------------------------------------------------------------------------
--    File Information: %W%
--    Revision: %I%
--    Date: %G% %U%
----------------------------------------------------------------------------------------------------

--#iftag fixpack_5

---------------------
--- HOST TABLES/VIEWS
---------------------

-- VE VIEW
CREATE VIEW BWM.VE_HOST (MAX_VALUE) AS
 SELECT MAX(C.COMP_ID)
     FROM TWG.CUR_COMP C
     WHERE C.COMPTYP_CD IN ('IP_HOST','IP_INTERFACE','BWM_HOST')
         ;

-- VD VIEW
CREATE VIEW BWM.VD_HOST(
    ORIG_HOST_ID,
    HOST_NM,
    LAST_IP_ADDRESS,
    CUST_NM,
    CENTR_NM)
    AS
 SELECT
  C1.COMP_ID AS ORIG_HOST_ID,
  C1.COMP_NM AS HOST_NM,
  VALUE(MIN(C2.COMPATTR_VAL),'N/A') AS LAST_IP_ADDRESS,
  CU.CUST_NM AS CUST_NM,
  CE.CENTR_NM AS CENTR_NM
 FROM
  TWG.CUR_COMP C1 LEFT OUTER JOIN TWG.CUR_COMPATTR C2
   ON C2.COMP_ID=C1.COMP_ID AND C2.ATTRTYP_CD='LAST_IP_ADDRESS',
  TWG.CUST CU,
  TWG.CENTR CE
 WHERE
  CU.CUST_ID=C1.CUST_ID AND CE.CENTR_CD=C1.CENTR_CD AND
  C1.COMPTYP_CD IN ('IP_HOST','BWM_HOST')
 GROUP BY
  C1.COMP_ID, C1.COMP_NM, CU.CUST_NM, CE.CENTR_NM
UNION
 SELECT
  C1.COMP_ID AS ORIG_HOST_ID,
  'N/A' AS HOST_NM,
  C1.COMP_NM AS LAST_IP_ADDRESS,
  CU.CUST_NM AS CUST_NM,
  CE.CENTR_NM AS CENTR_NM
 FROM
  TWG.CUR_COMP C1,
  TWG.CUST CU,
  TWG.CENTR CE
 WHERE
  CU.CUST_ID=C1.CUST_ID AND CE.CENTR_CD=C1.CENTR_CD AND
  C1.COMPTYP_CD IN ('IP_INTERFACE')
 GROUP BY
  C1.COMP_ID, C1.COMP_NM, CU.CUST_NM, CE.CENTR_NM
;



-- VE VIEW
CREATE VIEW BWM.VE_APP (MAX_VALUE) AS
 SELECT MAX(C.COMP_ID)
    FROM TWG.CUR_COMP C
    WHERE C.COMPTYP_CD IN ('J2EE_SERVER','BWM_PROBE')
    ;

--VE VIEW
CREATE VIEW BWM.VE_STG_TX_ND_HR (MAX_VALUE) AS
 SELECT MAX(M.MSMT_ID)
    FROM TWG.CUR_COMP C, TWG.MSMT M
    WHERE C.COMPTYP_CD='BWM_TX_NODE' AND C.COMP_ID=M.COMP_ID
;


---------------------
--- T_TX TABLES/VIEWS
---------------------

-- VE VIEW
CREATE VIEW BWM.VE_TX (MAX_VALUE) AS
 SELECT MAX(C.COMP_ID)
    FROM TWG.CUR_COMP C
    WHERE C.COMPTYP_CD IN ('BWM_TRANSACTION')
    ;

-- VD VIEW
CREATE VIEW BWM.VD_TX(
    ORIG_TX_ID,
    TX_NAME,
    TX_DESCRIPTION,
    URL_PROTOCOL,
    WEBSITE,
    WEBSITE_PATH,
    WEBSITE_QUERY)
    AS
 SELECT
  C0.COMP_ID AS ORIG_TX_ID,
  C0.COMP_NM AS TX_NAME,
  VALUE(MIN(C0.COMP_DS),' ') AS TX_DESCRIPTION,
  VALUE(MIN(CA1.COMPATTR_VAL),'N/A') AS URL_PROTOCOL,
  VALUE(MIN(CA2.COMPATTR_VAL),'N/A') AS WEBSITE,
  VALUE(MIN(CA3.COMPATTR_VAL),'N/A') AS WEBSITE_PATH,
  VALUE(MIN(CA4.COMPATTR_VAL),'N/A') AS WEBSITE_QUERY
 FROM
  TWG.CUR_COMP C0,
  TWG.CUR_COMP C1 LEFT OUTER JOIN TWG.CUR_COMPATTR CA1
   ON CA1.COMP_ID=C1.COMP_ID AND CA1.ATTRTYP_CD='URL_PROTOCOL',
  TWG.CUR_COMP C2 LEFT OUTER JOIN TWG.CUR_COMPATTR CA2
   ON CA2.COMP_ID=C2.COMP_ID AND CA2.ATTRTYP_CD='WEBSITE',
  TWG.CUR_COMP C3 LEFT OUTER JOIN TWG.CUR_COMPATTR CA3
   ON CA3.COMP_ID=C3.COMP_ID AND CA3.ATTRTYP_CD='WEBSITE_PATH',
  TWG.CUR_COMP C4 LEFT OUTER JOIN TWG.CUR_COMPATTR CA4
   ON CA4.COMP_ID=C4.COMP_ID AND CA4.ATTRTYP_CD='WEBSITE_QUERY',
  TWG.COMPRELN R
 WHERE
  C0.COMPTYP_CD IN ('BWM_TRANSACTION') AND
  C1.COMPTYP_CD IN ('BWM_TX_NODE') AND
  C1.COMP_ID=C2.COMP_ID AND
  C1.COMP_ID=C3.COMP_ID AND
  C1.COMP_ID=C4.COMP_ID AND
  R.RELNTYP_CD='INSTOF' AND
  R.COMP_SOURCE_ID=C1.COMP_ID AND
  R.COMP_TARGET_ID=C0.COMP_ID
 GROUP BY
  C0.COMP_ID,C0.COMP_NM,C0.COMP_DS
;

--------------------
---  STG_TX_ND_MET
--------------------
CREATE TABLE BWM.STG_TX_ND_MET(
    INSERT_DTTM TIMESTAMP,
    METRIC_ID INTEGER NOT NULL,
    MET_CATEGORY VARCHAR(254),
    MET_DESC VARCHAR(254),
    MET_NAME VARCHAR(254) NOT NULL,
    MET_UNITS VARCHAR(254),
    MIN_EXISTS CHAR(1) NOT NULL,
    MAX_EXISTS CHAR(1) NOT NULL,
    AVG_EXISTS CHAR(1) NOT NULL,
    TOTAL_EXISTS CHAR(1) NOT NULL,
    MSRC_NM VARCHAR(254),
    PRIMARY KEY(METRIC_ID))
    ;

-- VE VIEW
CREATE VIEW BWM.VE_TX_ND_MET (MAX_VALUE) AS
 SELECT MAX(METRIC_ID)
    FROM BWM.STG_TX_ND_MET
;

-- VD VIEW
CREATE VIEW BWM.VD_TX_ND_MET(
    ORIG_METRIC_ID,
    MET_CATEGORY,
    MET_DESC,
    MET_NAME,
    MET_UNITS,
    MIN_EXISTS,
    MAX_EXISTS,
    AVG_EXISTS,
    TOTAL_EXISTS,
    MSRC_NM)
    AS
 SELECT
  D.METRIC_ID AS ORIG_METRIC_ID,
  D.MET_CATEGORY AS MET_CATEGORY,
  D.MET_DESC AS MET_DESC,
  D.MET_NAME AS MET_NAME,
  D.MET_UNITS AS MET_UNITS,
  D.MIN_EXISTS AS MIN_EXISTS,
  D.MAX_EXISTS AS MAX_EXISTS,
  D.AVG_EXISTS AS AVG_EXISTS,
  D.TOTAL_EXISTS AS TOTAL_EXISTS,
  D.MSRC_NM AS MSRC_NM
 FROM BWM.STG_TX_ND_MET D
;

-- VE VIEW
CREATE VIEW BWM.VE_TX_ND (MAX_VALUE) AS
 SELECT MAX(C.COMP_ID)
    FROM TWG.CUR_COMP C
    WHERE C.COMPTYP_CD='BWM_TX_NODE'
;

CREATE SEQUENCE BWM.THR_MSMT_ID_SEQ
 START WITH -1 INCREMENT BY -1 NO MAXVALUE NO CYCLE CACHE 24
;


-----------------------------
-- lookup table for customer
-----------------------------
create table bwm.cust_lookup (
   cust_id  integer,
   value    char(32)
);

--------------------------
-- lookup table for centr
--------------------------
create table bwm.centr_lookup (
    centr_cd    char(6),
    value       char(32)
);

--Insert data into lookup tables to setup a single customer/center environment.
declare global temporary table bwm_cust_lookup (
   cust_id  integer,
   value    char(32)
)
with replace on commit preserve rows not logged
;

insert into session.bwm_cust_lookup values (1, '@');

INSERT INTO BWM.cust_lookup
SELECT * FROM session.bwm_cust_lookup s
WHERE NOT EXISTS (
   SELECT 1 FROM
   BWM.cust_lookup t WHERE
   t.cust_id = s.cust_id
);

declare global temporary table bwm_centr_lookup (
    centr_cd    char(3),
    value       char(32)
)
with replace on commit preserve rows not logged
;

insert into session.bwm_centr_lookup values ('CDW', '@');

INSERT INTO BWM.centr_lookup
SELECT * FROM session.bwm_centr_lookup s
WHERE NOT EXISTS (
   SELECT 1 FROM
   BWM.centr_lookup t WHERE
   t.centr_cd = s.centr_cd
);

--#endtag fixpack_5
