-------------------------------------------------------------------------------
--   OCO Source Materials
--
--   Licensed Materials - Property of IBM
--
--   5724-C02
--
--   (C) Copyright IBM Corp. 2003  All Rights Reserved.
--
--   US Government Users Restricted Rights - Use, duplication or
--   disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
-------------------------------------------------------------------------------
--    File Information: %W%
--    Revision: %I%
--    Date: %G% %U%
-------------------------------------------------------------------------------


--------------------------------------------
-- Component Conversion
--------------------------------------------



-- Put 51 BWM_STI and BWM_QOS into map table
-- Generate TX NODE ID automatically
--#IGNORE_ERROR
INSERT INTO BWM.UP_MAP_PROBE (
    ORIG_COMP_ID,
    TX_ND_ID,
    PROBE_TYPE)
 SELECT
  COMP_ID,NEXTVAL FOR BWM.UP_TX_ND_ID_SEQ,'STI'
 FROM
  TWG.COMP
 WHERE
  COMPTYP_CD IN ('BWM_STI')
 ORDER BY
  COMP_STRT_DTTM ASC
;

--#IGNORE_ERROR
INSERT INTO BWM.UP_MAP_PROBE (
    ORIG_COMP_ID,
    TX_ND_ID,
    PROBE_TYPE)
 SELECT
  COMP_ID,NEXTVAL FOR BWM.UP_TX_ND_ID_SEQ,'QOS'
 FROM
  TWG.COMP
 WHERE
  COMPTYP_CD IN ('BWM_QOS')
 ORDER BY
  COMP_STRT_DTTM ASC
;


--#IGNORE_ERROR
UPDATE BWM.UP_MAP_PROBE B
 SET IP_HOST_COMP_ID=
 (
  SELECT
   MAX(C_EP.COMP_ID)
  FROM
   TWG.COMP C_EP,
   TWG.COMPRELN R2
  WHERE
   C_EP.COMPTYP_CD='BWM_EP' AND
   R2.COMP_SOURCE_ID=C_EP.COMP_ID AND
   R2.COMP_TARGET_ID=B.ORIG_COMP_ID AND
   R2.RELNTYP_CD='PCHILD'
 )
 WHERE
  IP_HOST_COMP_ID IS NULL
;

--#IGNORE_ERROR
INSERT INTO TWG.COMP (
    COMPTYP_CD,
    CENTR_CD,
    CUST_ID,
    COMP_CORR_ID,
    COMP_NM,
    COMP_STRT_DTTM,
    COMP_END_DTTM,
    COMP_DS)
 SELECT
  'BWM_HOST',
  'CDW',
  1,
  C.COMP_ID,
  CONCAT('(51)',MIN(C.COMP_NM)),
  MIN(C.COMP_STRT_DTTM),
  MAX(C.COMP_END_DTTM),
  MIN(C.COMP_DS)
 FROM
  TWG.COMP C,
  BWM.UP_MAP_PROBE B
 WHERE
  C.COMPTYP_CD='BWM_EP' AND
  C.COMP_ID=B.IP_HOST_COMP_ID AND
  NOT EXISTS
  (
   SELECT 1
   FROM TWG.COMP E
   WHERE
    E.COMPTYP_CD='BWM_HOST' AND
    E.CENTR_CD='CDW' AND
    E.CUST_ID=1 AND
    E.COMP_NM=CONCAT('(51)',C.COMP_NM)
  )
 GROUP BY
  C.COMP_ID
;

insert into BWM.MIGR_COMP (MIGR_ID,ORIG_NM, ORIG_ID, ORIG_CTYPE, NEW_NM, NEW_ID, NEW_CTYPE, CREATE_DT)
select distinct
    0,
    c1.comp_nm,
    c1.comp_id,
    'BWM_EP',
    c2.comp_nm,	
    c2.comp_id,
    'BWM_HOST',
    CURRENT timestamp - CURRENT timezone
from 
    twg.comp c1,
    twg.comp c2,
    BWM.UP_MAP_PROBE B
where
  C1.COMPTYP_CD='BWM_EP' AND
  C1.COMP_ID=B.IP_HOST_COMP_ID AND
  C2.COMPTYP_CD='BWM_HOST' AND
  C2.COMP_CORR_ID=B.IP_HOST_COMP_ID
;

    
--#IGNORE_ERROR
UPDATE BWM.UP_MAP_PROBE B
 SET IP_HOST_COMP_ID=
 (
  SELECT COMP_ID
  FROM TWG.COMP C
  WHERE
   C.COMPTYP_CD='BWM_HOST' AND
   C.COMP_CORR_ID=B.IP_HOST_COMP_ID
 );

-- Create 52 BWM_PROBE based on 51 BWM_STI and BWM_QOS
-- On one IP_HOST there are at most one STI and/or QOS type of PROBE
--#IGNORE_ERROR
INSERT INTO TWG.COMP (
    COMPTYP_CD,
    CENTR_CD,
    CUST_ID,
    COMP_CORR_ID,
    COMP_NM,
    COMP_STRT_DTTM,
    COMP_END_DTTM,
    COMP_DS)
 SELECT
  'BWM_PROBE',
  'CDW',
  1,
  MIN(B.ORIG_COMP_ID),
  CONCAT(CONCAT('(51)',B.PROBE_TYPE),H.COMP_NM),
  MIN(C.COMP_STRT_DTTM),
  MAX(C.COMP_END_DTTM),
  CONCAT(CONCAT(B.PROBE_TYPE,'(51) runs on '),H.COMP_NM)
 FROM
  TWG.COMP C,
  BWM.UP_MAP_PROBE B,
  TWG.COMP H
 WHERE
  C.COMP_ID=B.ORIG_COMP_ID AND
  H.COMP_ID=B.IP_HOST_COMP_ID AND
  NOT EXISTS
  (
   SELECT 1
   FROM TWG.COMP E
   WHERE
    E.COMPTYP_CD='BWM_PROBE' AND
    E.CENTR_CD='CDW' AND
    E.CUST_ID=1 AND
    E.COMP_NM=CONCAT(CONCAT('(51)',B.PROBE_TYPE),H.COMP_NM)
  )
 GROUP BY
  B.PROBE_TYPE,H.COMP_NM
;

-- Fill the map table with new PROBE's COMP ID
-- Link BWM_STI and BWM_QOS with BWM_PROBE
--#IGNORE_ERROR
UPDATE BWM.UP_MAP_PROBE B
 SET NEW_COMP_ID=
    (
     SELECT COMP_ID
     FROM TWG.COMP C
     WHERE
      C.COMPTYP_CD='BWM_PROBE' AND
      C.COMP_CORR_ID=B.ORIG_COMP_ID
    );
--#IGNORE_ERROR
UPDATE BWM.UP_MAP_PROBE B
 SET NEW_COMP_ID=
    (
     SELECT A.NEW_COMP_ID
     FROM BWM.UP_MAP_PROBE A
     WHERE
      A.NEW_COMP_ID IS NOT NULL AND
      A.PROBE_TYPE=B.PROBE_TYPE AND
      A.IP_HOST_COMP_ID=B.IP_HOST_COMP_ID
     )
 WHERE B.NEW_COMP_ID IS NULL
;

-- Create TX NODE for each BWM_STI and BWM_QOS
-- Since one BWM_PROBE COMP ID may link to mutiple BWM_STI and BWM_QOS,
-- One BWM_PROBE COMP ID may link to mutiple BWM_TX_NODE
--#IGNORE_ERROR
INSERT INTO TWG.COMP (
    COMPTYP_CD,
    CENTR_CD,
    CUST_ID,
    COMP_CORR_ID,
    COMP_NM,
    COMP_STRT_DTTM,
    COMP_END_DTTM,
    COMP_DS)
 SELECT
  'BWM_TX_NODE',
  'CDW',
  1,
  B.ORIG_COMP_ID,
  CONCAT('(51)Transaction_Node_',CHAR(B.TX_ND_ID)),
  C.COMP_STRT_DTTM,
  C.COMP_END_DTTM,
  C.COMP_DS
 FROM
  TWG.COMP C,
  BWM.UP_MAP_PROBE B
 WHERE
  C.COMP_ID=B.ORIG_COMP_ID AND
  NOT EXISTS
  (
   SELECT 1
   FROM TWG.COMP E
   WHERE
    E.COMPTYP_CD='BWM_TX_NODE' AND
    E.CENTR_CD='CDW' AND
    E.CUST_ID=1 AND
    E.COMP_CORR_ID=B.ORIG_COMP_ID
  )
;
--#IGNORE_ERROR
UPDATE BWM.UP_MAP_PROBE B
 SET TX_ND_COMP_ID=
    (
     SELECT COMP_ID
     FROM TWG.COMP C
     WHERE
      C.COMPTYP_CD='BWM_TX_NODE' AND
      C.COMP_CORR_ID=B.ORIG_COMP_ID
    );

-- Record the WEBSITE's COMP ID that linked to BWM_QOS
--#IGNORE_ERROR
UPDATE BWM.UP_MAP_PROBE B
 SET WEBSITE_ID=
    (
     SELECT W.COMP_ID
     FROM
      TWG.COMP W,
      TWG.COMPRELN R
     WHERE
      R.COMP_SOURCE_ID=B.ORIG_COMP_ID AND R.COMP_TARGET_ID=W.COMP_ID AND
      R.RELNTYP_CD='MONITR' AND
      B.PROBE_TYPE='QOS' AND W.COMPTYP_CD='WEBSITE'
    );

-- Record the WEBSITE_PATH's COMP ID that linked to BWM_QOS
--#IGNORE_ERROR
UPDATE BWM.UP_MAP_PROBE B
 SET WEBSITE_PATH_ID=
    (
     SELECT MAX(W.COMP_ID)
     FROM
      TWG.COMP W,
      TWG.COMPRELN R
     WHERE
      R.COMP_SOURCE_ID=B.WEBSITE_ID AND R.COMP_TARGET_ID=W.COMP_ID AND
      R.RELNTYP_CD='PCHILD' AND W.COMPTYP_CD='WEBSITE_PATH'
    );

-- Record the WEBSITE_QUREY's COMP ID that linked to BWM_QOS
--#IGNORE_ERROR
UPDATE BWM.UP_MAP_PROBE B
 SET WEBSITE_QUERY_ID=
    (
     SELECT MAX(W.COMP_ID)
     FROM
      TWG.COMP W,
      TWG.COMPRELN R
     WHERE
      R.COMP_SOURCE_ID=B.WEBSITE_PATH_ID AND R.COMP_TARGET_ID=W.COMP_ID AND
      R.RELNTYP_CD='PCHILD' AND W.COMPTYP_CD='WEBSITE_QUERY'
    );

-- Mark the length of WEBSITE, WEBSITE_PATH and WEBSITE_QUERY's name/long name
--#IGNORE_ERROR
UPDATE BWM.UP_MAP_PROBE B
 SET SITE_LEN=
    (
     SELECT LENGTH(C.COMP_NM)
     FROM TWG.COMP C
     WHERE C.COMP_ID=B.WEBSITE_ID
    );

--#IGNORE_ERROR
UPDATE BWM.UP_MAP_PROBE B
 SET PATH_LEN=
    (
     SELECT LENGTH(C.COMP_NM)
     FROM TWG.COMP C
     WHERE C.COMP_ID=B.WEBSITE_PATH_ID
    );

--#IGNORE_ERROR
UPDATE BWM.UP_MAP_PROBE B
 SET QUERY_LEN=
    (
     SELECT LENGTH(C.COMP_NM)
     FROM TWG.COMP C
     WHERE C.COMP_ID=B.WEBSITE_QUERY_ID
    );

--#IGNORE_ERROR
UPDATE BWM.UP_MAP_PROBE B
 SET SITE_LONG_LEN=
    (
     SELECT LENGTH(L.COMP_NM)
     FROM BWM.COMP_LONG L
     WHERE L.COMP_ID=B.WEBSITE_ID
    );

--#IGNORE_ERROR
UPDATE BWM.UP_MAP_PROBE B
 SET PATH_LONG_LEN=
    (
     SELECT LENGTH(L.COMP_NM)
     FROM BWM.COMP_LONG L
     WHERE L.COMP_ID=B.WEBSITE_PATH_ID
    );

--#IGNORE_ERROR
UPDATE BWM.UP_MAP_PROBE B
 SET QUERY_LONG_LEN=
    (
     SELECT LENGTH(L.COMP_NM)
     FROM BWM.COMP_LONG L
     WHERE L.COMP_ID=B.WEBSITE_QUERY_ID
    );

-- Build the BWM_TRANSACTION's name to the longest
--#IGNORE_ERROR
INSERT INTO BWM.UP_COMP_LONG (
    COMP_ID,
    COMP_NM)
 SELECT
  B.ORIG_COMP_ID,
  C.COMP_NM
 FROM
  BWM.UP_MAP_PROBE B,
  TWG.COMP C
 WHERE
  B.ORIG_COMP_ID=C.COMP_ID AND B.PROBE_TYPE='QOS'
;

--#IGNORE_ERROR
UPDATE BWM.UP_COMP_LONG L
 SET COMP_NM=
    (
     SELECT
       CONCAT(L.COMP_NM,V.LONGER_NAME)
     FROM
      BWM.UP_MAP_PROBE B,
      BWM.UP_WEB_NAME V
     WHERE
      B.ORIG_COMP_ID=L.COMP_ID AND
      B.WEBSITE_ID=V.COMP_ID
    );

--#IGNORE_ERROR
UPDATE BWM.UP_COMP_LONG L
 SET COMP_NM=
    (
     SELECT
       CONCAT(L.COMP_NM,V.LONGER_NAME)
     FROM
      BWM.UP_MAP_PROBE B,
      BWM.UP_WEB_NAME V
     WHERE
      B.ORIG_COMP_ID=L.COMP_ID AND
      B.WEBSITE_PATH_ID=V.COMP_ID
    );

--#IGNORE_ERROR
UPDATE BWM.UP_COMP_LONG L
 SET COMP_NM=
    (
     SELECT
       CONCAT(L.COMP_NM,CONCAT('/',V.LONGER_NAME))
     FROM
      BWM.UP_MAP_PROBE B,
      BWM.UP_WEB_NAME V
     WHERE
      B.ORIG_COMP_ID=L.COMP_ID AND
      B.WEBSITE_QUERY_ID=V.COMP_ID
    );

-- Create Transaction for each TX NODE
--#IGNORE_ERROR
INSERT INTO TWG.COMP (
    COMPTYP_CD,
    CENTR_CD,
    CUST_ID,
    COMP_CORR_ID,
    COMP_NM,
    COMP_STRT_DTTM,
    COMP_END_DTTM,
    COMP_DS)
 SELECT
  'BWM_TRANSACTION',
  'CDW',
  1,
  B.ORIG_COMP_ID,
  CONCAT('(51)',C.COMP_NM),
  C.COMP_STRT_DTTM,
  C.COMP_END_DTTM,
  C.COMP_DS
 FROM
  TWG.COMP C,
  BWM.UP_MAP_PROBE B
 WHERE
  C.COMP_ID=B.ORIG_COMP_ID AND
  B.PROBE_TYPE='STI' AND
  NOT EXISTS
  (
   SELECT 1
   FROM TWG.COMP E
   WHERE
    E.COMPTYP_CD='BWM_TRANSACTION' AND
    E.CENTR_CD='CDW' AND
    E.CUST_ID=1 AND
    E.COMP_NM=CONCAT('(51)',C.COMP_NM)
  )
;

--#IGNORE_ERROR
INSERT INTO TWG.COMP (
    COMPTYP_CD,
    CENTR_CD,
    CUST_ID,
    COMP_CORR_ID,
    COMP_NM,
    COMP_STRT_DTTM,
    COMP_END_DTTM,
    COMP_DS)
 SELECT
  'BWM_TRANSACTION',
  'CDW',
  1,
  B.ORIG_COMP_ID,
  CONCAT('(51)',CHAR(L.COMP_NM)),
  C.COMP_STRT_DTTM,
  C.COMP_END_DTTM,
  C.COMP_DS
 FROM
  TWG.COMP C,
  BWM.UP_MAP_PROBE B,
  BWM.UP_COMP_LONG L
 WHERE
  C.COMP_ID=B.ORIG_COMP_ID AND
  B.PROBE_TYPE='QOS' AND
  L.COMP_ID=B.ORIG_COMP_ID AND
  LENGTH(L.COMP_NM)<=250  AND
  NOT EXISTS
  (
   SELECT 1
   FROM TWG.COMP E
   WHERE
    E.COMPTYP_CD='BWM_TRANSACTION' AND
    E.CENTR_CD='CDW' AND
    E.CUST_ID=1 AND
    E.COMP_NM=CONCAT('(51)',CHAR(L.COMP_NM))
  )
 UNION
 SELECT
  'BWM_TRANSACTION',
  'CDW',
  1,
  B.ORIG_COMP_ID,
  CONCAT('(51)',CHAR(SUBSTR(L.COMP_NM,1,250))),
  C.COMP_STRT_DTTM,
  C.COMP_END_DTTM,
  C.COMP_DS
 FROM
  TWG.COMP C,
  BWM.UP_MAP_PROBE B,
  BWM.UP_COMP_LONG L
 WHERE
  C.COMP_ID=B.ORIG_COMP_ID AND
  B.PROBE_TYPE='QOS' AND
  L.COMP_ID=B.ORIG_COMP_ID AND
  LENGTH(L.COMP_NM)>250 AND
  NOT EXISTS
  (
   SELECT 1
   FROM TWG.COMP E
   WHERE
    E.COMPTYP_CD='BWM_TRANSACTION' AND
    E.CENTR_CD='CDW' AND
    E.CUST_ID=1 AND
    E.COMP_NM=CONCAT('(51)',CHAR(SUBSTR(L.COMP_NM,1,250)))
  )
;

--#IGNORE_ERROR
UPDATE BWM.UP_MAP_PROBE B
 SET TX_COMP_ID=
    (
     SELECT COMP_ID
     FROM TWG.COMP C
     WHERE
      C.COMPTYP_CD='BWM_TRANSACTION' AND
      C.COMP_CORR_ID=B.ORIG_COMP_ID
    );

-- Store BWM_TRANSACTION's long name
--#IGNORE_ERROR
INSERT INTO BWM.COMP_NAME_LONG (
    COMP_ID,
    COMP_NM,
    COMP_DS,
    COMPTYP_CD)
 SELECT
  B.TX_COMP_ID,
  CHAR(L.COMP_NM),
  C.COMP_DS,
  C.COMPTYP_CD
 FROM
  BWM.UP_MAP_PROBE B,
  BWM.UP_COMP_LONG L,
  TWG.COMP C
 WHERE
  B.ORIG_COMP_ID=L.COMP_ID AND
  LENGTH(L.COMP_NM)>254 AND
  LENGTH(L.COMP_NM)<4000 AND
  L.COMP_ID=C.COMP_ID AND
  NOT EXISTS
  (
   SELECT 1
   FROM BWM.COMP_NAME_LONG E
   WHERE
    E.COMP_ID=B.TX_COMP_ID AND
    E.COMP_NM=CHAR(L.COMP_NM) AND
    E.COMP_DS=C.COMP_DS AND
    E.COMPTYP_CD=C.COMPTYP_CD
  )
 UNION
 SELECT
  B.TX_COMP_ID,
  CHAR(SUBSTR(L.COMP_NM,1,4000)),
  C.COMP_DS,
  C.COMPTYP_CD
 FROM
  BWM.UP_MAP_PROBE B,
  BWM.UP_COMP_LONG L,
  TWG.COMP C
 WHERE
  B.ORIG_COMP_ID=L.COMP_ID AND
  LENGTH(L.COMP_NM)>4000 AND
  L.COMP_ID=C.COMP_ID AND
  NOT EXISTS
  (
   SELECT 1
   FROM BWM.COMP_NAME_LONG E
   WHERE
    E.COMP_ID=B.TX_COMP_ID AND
    E.COMP_NM=CHAR(SUBSTR(L.COMP_NM,1,4000)) AND
    E.COMP_DS=C.COMP_DS AND
    E.COMPTYP_CD=C.COMPTYP_CD
  )
;

--------------------------------------------
-- Attribute Conversion
--------------------------------------------

-- Convert old component WEBSITE, WEBSITE_PATH and WEBSITE_QUERY into
-- new attribute WEBSITE, WEBSITE_PATH and WEBSITE_QUERY of component TRANSACTION Node
--#IGNORE_ERROR
INSERT INTO TWG.COMPATTR (
    COMP_ID,
    ATTRTYP_CD,
    COMPATTR_STRT_DTTM,
    COMPATTR_END_DTTM,
    COMPATTR_VAL)
 SELECT
  B.TX_ND_COMP_ID,
  C.COMPTYP_CD,
  C.COMP_STRT_DTTM,
  C.COMP_END_DTTM,
  C.COMP_NM
 FROM
  BWM.UP_MAP_PROBE B,
  TWG.COMP C
 WHERE
  (
   B.WEBSITE_ID=C.COMP_ID OR
   B.WEBSITE_PATH_ID=C.COMP_ID OR
   B.WEBSITE_QUERY_ID=C.COMP_ID
  ) AND
  NOT EXISTS (
   SELECT 1
   FROM TWG.COMPATTR E
   WHERE
    E.COMP_ID=B.TX_ND_COMP_ID AND
    E.ATTRTYP_CD=C.COMPTYP_CD AND
    E.COMPATTR_STRT_DTTM=C.COMP_STRT_DTTM AND
    E.COMPATTR_END_DTTM=C.COMP_END_DTTM AND
    E.COMPATTR_VAL=C.COMP_NM
  )
;

-- Store BWM_TRANSACTION's long attribute value
--#IGNORE_ERROR
INSERT INTO BWM.COMP_ATTR_LONG (
    COMPATTR_ID,
    COMP_ID,
    COMPATTR_VAL,
    ATTRTYP_CD)
 SELECT
  A.COMPATTR_ID,
  A.COMP_ID,
  L.COMP_NM,
  A.ATTRTYP_CD
 FROM
  TWG.COMPATTR A,
  TWG.COMP C,
  BWM.UP_MAP_PROBE B,
  BWM.COMP_LONG L
 WHERE
  B.TX_ND_COMP_ID=A.COMP_ID AND
  A.ATTRTYP_CD=C.COMPTYP_CD AND
  C.COMP_ID=L.COMP_ID AND
 (
  B.WEBSITE_ID=C.COMP_ID OR
  B.WEBSITE_PATH_ID=C.COMP_ID OR
  B.WEBSITE_QUERY_ID=C.COMP_ID
 ) AND
 NOT EXISTS
 (
  SELECT 1
  FROM BWM.COMP_ATTR_LONG E
  WHERE
   E.COMPATTR_ID=A.COMPATTR_ID AND
   E.COMP_ID=A.COMP_ID AND
   E.ATTRTYP_CD=A.ATTRTYP_CD
 )
;

-- Convert old attribute URL_PROTOCOL to new TX component
--#IGNORE_ERROR
INSERT INTO TWG.COMPATTR (
    COMP_ID,
    ATTRTYP_CD,
    COMPATTR_STRT_DTTM,
    COMPATTR_END_DTTM,
    COMPATTR_VAL)
 SELECT
  B.TX_ND_COMP_ID,
  'URL_PROTOCOL',
  A.COMPATTR_STRT_DTTM,
  A.COMPATTR_END_DTTM,
  A.COMPATTR_VAL
 FROM
  BWM.UP_MAP_PROBE B,
  TWG.COMPATTR A
 WHERE
  B.WEBSITE_ID=A.COMP_ID AND
  A.ATTRTYP_CD='URL_PROTOCOL' AND
  NOT EXISTS
  (
   SELECT 1
   FROM TWG.COMPATTR E
   WHERE
    E.COMP_ID=B.TX_ND_COMP_ID AND
    E.ATTRTYP_CD='URL_PROTOCOL' AND
    E.COMPATTR_STRT_DTTM=A.COMPATTR_STRT_DTTM AND
    E.COMPATTR_END_DTTM=A.COMPATTR_END_DTTM
  )
;


--------------------------------------------
-- Relationship Conversion
--------------------------------------------

-- Insert relationship between BWM_PROBE and IP_HOST

INSERT INTO TWG.COMPRELN(
    COMP_SOURCE_ID,
    COMP_TARGET_ID,
    RELNTYP_CD,
    COMPRELN_STRT_DTTM,
    COMPRELN_END_DTTM)
 SELECT
  B.NEW_COMP_ID,
  B.IP_HOST_COMP_ID,
  'RUNSON',
  MIN(R2.COMPRELN_STRT_DTTM),
  MAX(R2.COMPRELN_END_DTTM)
 FROM
  BWM.UP_MAP_PROBE B,
  TWG.COMP EP,
  TWG.COMPRELN R1,
  TWG.COMPRELN R2
 WHERE
--  R1.COMP_SOURCE_ID=EP.COMP_ID AND
--  R1.COMP_TARGET_ID=B.IP_HOST_COMP_ID AND
--  R1.RELNTYP_CD='RUNSON' AND
  R2.COMP_SOURCE_ID=EP.COMP_ID AND
  R2.COMP_TARGET_ID=B.ORIG_COMP_ID AND
  R2.RELNTYP_CD='PCHILD' AND
  NOT EXISTS
  (
   SELECT 1
   FROM TWG.COMPRELN E
   WHERE
    E.COMP_SOURCE_ID=B.NEW_COMP_ID AND
    E.COMP_TARGET_ID=B.IP_HOST_COMP_ID AND
    E.RELNTYP_CD='RUNSON'
  )
 GROUP BY B.NEW_COMP_ID,B.IP_HOST_COMP_ID
;

-- Insert relationship between BWM_PROBE and BWM_TRANSACTION
--#IGNORE_ERROR
INSERT INTO TWG.COMPRELN(
    COMP_SOURCE_ID,
    COMP_TARGET_ID,
    RELNTYP_CD,
    COMPRELN_STRT_DTTM,
    COMPRELN_END_DTTM)
 SELECT
  B.NEW_COMP_ID,
  B.TX_COMP_ID,
  'PCHILD',
  C.COMP_STRT_DTTM,
  C.COMP_END_DTTM
 FROM
  BWM.UP_MAP_PROBE B,
  TWG.COMP C
 WHERE
  B.TX_COMP_ID=C.COMP_ID AND
  NOT EXISTS
  (
   SELECT 1
   FROM TWG.COMPRELN E
   WHERE
    E.COMP_SOURCE_ID=B.NEW_COMP_ID AND
    E.COMP_TARGET_ID=B.TX_COMP_ID AND
    E.RELNTYP_CD='PCHILD' AND
    E.COMPRELN_STRT_DTTM=C.COMP_STRT_DTTM AND
    E.COMPRELN_END_DTTM=C.COMP_END_DTTM
  )
;

-- Insert relationship between BWM_PROBE and BWM_TX_NODE
--#IGNORE_ERROR
INSERT INTO TWG.COMPRELN(
    COMP_SOURCE_ID,
    COMP_TARGET_ID,
    RELNTYP_CD,
    COMPRELN_STRT_DTTM,
    COMPRELN_END_DTTM)
 SELECT
  B.NEW_COMP_ID,
  B.TX_ND_COMP_ID,
  'INVOKE',
  C.COMP_STRT_DTTM,
  C.COMP_END_DTTM
 FROM
  BWM.UP_MAP_PROBE B,
  TWG.COMP C
 WHERE
  B.TX_ND_COMP_ID=C.COMP_ID AND
  NOT EXISTS
  (
   SELECT 1
   FROM TWG.COMPRELN E
   WHERE
    E.COMP_SOURCE_ID=B.NEW_COMP_ID AND
    E.COMP_TARGET_ID=B.TX_ND_COMP_ID AND
    E.RELNTYP_CD='INVOKE' AND
    E.COMPRELN_STRT_DTTM=C.COMP_STRT_DTTM AND
    E.COMPRELN_END_DTTM=C.COMP_END_DTTM
  )
;

-- Insert relationship between BWM_TX_NODE and BWM_TRANSACTION
--#IGNORE_ERROR
INSERT INTO TWG.COMPRELN(
    COMP_SOURCE_ID,
    COMP_TARGET_ID,
    RELNTYP_CD,
    COMPRELN_STRT_DTTM,
    COMPRELN_END_DTTM)
 SELECT
  B.TX_ND_COMP_ID,
  B.TX_COMP_ID,
  'INSTOF',
  C.COMP_STRT_DTTM,
  C.COMP_END_DTTM
 FROM
  BWM.UP_MAP_PROBE B,
  TWG.COMP C
 WHERE
  B.TX_ND_COMP_ID=C.COMP_ID AND
  NOT EXISTS
  (
   SELECT 1
   FROM TWG.COMPRELN E
   WHERE
    E.COMP_SOURCE_ID=B.TX_ND_COMP_ID AND
    E.COMP_TARGET_ID=B.TX_COMP_ID AND
    E.RELNTYP_CD='INSTOF' AND
    E.COMPRELN_STRT_DTTM=C.COMP_STRT_DTTM AND
    E.COMPRELN_END_DTTM=C.COMP_END_DTTM
  )
;

-- To reset
--#IGNORE_ERROR
UPDATE TWG.COMP ND
 SET
  COMP_NM=
  (
   SELECT TX.COMP_NM
   FROM
    TWG.COMP TX,
    TWG.COMPRELN R
   WHERE
    TX.COMPTYP_CD='BWM_TRANSACTION' AND
    R.COMP_SOURCE_ID=ND.COMP_ID AND
    R.COMP_TARGET_ID=TX.COMP_ID AND
    R.RELNTYP_CD='INSTOF'
  )
 WHERE
  ND.COMPTYP_CD='BWM_TX_NODE' AND
  ND.COMP_NM LIKE '(51)Transaction_Node_%'
;

 -- Place TX_NODE into the BWM.MIGR_COMP table
insert into BWM.MIGR_COMP (MIGR_ID,ORIG_NM, ORIG_ID, ORIG_CTYPE, NEW_NM, NEW_ID, NEW_CTYPE, CREATE_DT)
select distinct
    0,
    c1.comp_nm,    
    c1.comp_id,
    'BWM_STI',
    c2.comp_nm,
    c2.comp_id,
    'BWM_TX_NODE',
    CURRENT timestamp - CURRENT timezone
from 
    twg.comp c1,
    twg.comp c2,
    BWM.UP_MAP_PROBE B
where
  C1.COMPTYP_CD ='BWM_STI' AND
  C1.COMP_ID=B.ORIG_COMP_ID AND
  C2.COMPTYP_CD='BWM_TX_NODE' AND
  C2.COMP_CORR_ID=B.ORIG_COMP_ID
;

 -- Place TX_NODE into the BWM.MIGR_COMP table
insert into BWM.MIGR_COMP (MIGR_ID,ORIG_NM, ORIG_ID, ORIG_CTYPE, NEW_NM, NEW_ID, NEW_CTYPE, CREATE_DT)
select distinct
    0,
    c1.comp_nm,
    c1.comp_id,
    'BWM_QOS',
    c2.comp_nm,
    c2.comp_id,
    'BWM_TX_NODE',
    CURRENT timestamp - CURRENT timezone
from 
    twg.comp c1,
    twg.comp c2,
    BWM.UP_MAP_PROBE B
where
  C1.COMPTYP_CD ='BWM_QOS' AND
  C1.COMP_ID=B.ORIG_COMP_ID AND
  C2.COMPTYP_CD='BWM_TX_NODE' AND
  C2.COMP_CORR_ID=B.ORIG_COMP_ID
;


-- Insert relationship between BWM_TX_NODE and IP_HOST
--#IGNORE_ERROR
INSERT INTO TWG.COMPRELN(
    COMP_SOURCE_ID,
    COMP_TARGET_ID,
    RELNTYP_CD,
    COMPRELN_STRT_DTTM,
    COMPRELN_END_DTTM)
 SELECT
  B.TX_ND_COMP_ID,
  B.IP_HOST_COMP_ID,
  'RUNSON',
  C.COMP_STRT_DTTM,
  C.COMP_END_DTTM
 FROM
  BWM.UP_MAP_PROBE B,
  TWG.COMP C
 WHERE
  B.TX_ND_COMP_ID=C.COMP_ID AND

  NOT EXISTS
  (
   SELECT 1
   FROM TWG.COMPRELN E
   WHERE
    E.COMP_SOURCE_ID=B.TX_ND_COMP_ID AND
    E.COMP_TARGET_ID=B.IP_HOST_COMP_ID AND
    E.RELNTYP_CD='RUNSON' AND
    E.COMPRELN_STRT_DTTM=C.COMP_STRT_DTTM AND
    E.COMPRELN_END_DTTM=C.COMP_END_DTTM
  )
;
--#IGNORE_ERROR
INSERT INTO TWG.COMP (
    COMPTYP_CD,
    CENTR_CD,
    CUST_ID,
    COMP_NM,
    COMP_STRT_DTTM,
    COMP_END_DTTM,
    COMP_DS)
 SELECT
  'IP_HOST',
  'CDW',
  1,
  A.COMPATTR_VAL,
  MIN(A.COMPATTR_STRT_DTTM),
  MAX(A.COMPATTR_END_DTTM),
  'Original TMTP 5.1 attribute BWM_VIRTUAL_HOST'
 FROM
  BWM.UP_MAP_PROBE B,
  TWG.COMPATTR A
 WHERE
  B.ORIG_COMP_ID=A.COMP_ID AND
  A.ATTRTYP_CD='BWM_VIRTUAL_HOST' AND
  NOT EXISTS
  (
   SELECT 1
   FROM TWG.COMP C
   WHERE
    C.COMPTYP_CD='IP_HOST' AND
    C.COMP_NM=A.COMPATTR_VAL
  )
 GROUP BY A.COMPATTR_VAL
;
--#IGNORE_ERROR
INSERT INTO TWG.COMPRELN(
    COMP_SOURCE_ID,
    COMP_TARGET_ID,
    RELNTYP_CD,
    COMPRELN_STRT_DTTM,
    COMPRELN_END_DTTM)
 SELECT
  B.TX_ND_COMP_ID,
  C.COMP_ID,
  'RUNSON',
  C.COMP_STRT_DTTM,
  C.COMP_END_DTTM
 FROM
  BWM.UP_MAP_PROBE B,
  TWG.COMP C,
  TWG.COMPATTR A
 WHERE
  B.ORIG_COMP_ID=A.COMP_ID AND
  A.ATTRTYP_CD='BWM_VIRTUAL_HOST' AND
  C.COMPTYP_CD='IP_HOST' AND
  C.COMP_NM=A.COMPATTR_VAL AND
  NOT EXISTS
  (
   SELECT 1
   FROM TWG.COMPRELN E
   WHERE
    E.COMP_SOURCE_ID=B.TX_ND_COMP_ID AND
    E.COMP_TARGET_ID=C.COMP_ID AND
    E.RELNTYP_CD='RUNSON' AND
    E.COMPRELN_STRT_DTTM=C.COMP_STRT_DTTM AND
    E.COMPRELN_END_DTTM=C.COMP_END_DTTM
  )
;

--------------------------------------------
-- Measurement Migration
--------------------------------------------
--#IGNORE_ERROR
INSERT INTO TWG.MSMT (
    COMP_ID,
    MSMTTYP_ID,
    TMSUM_CD,
    MSMT_STRT_DT,
    MSMT_STRT_TM,
    MSMT_MIN_VAL,
    MSMT_MAX_VAL,
    MSMT_AVG_VAL,
    MSMT_TOT_VAL,
    MSMT_SMPL_CNT,
    MSMT_ERR_CNT)
SELECT
  B.TX_ND_COMP_ID,
  M.MSMTTYP_ID,
  M.TMSUM_CD,
  M.MSMT_STRT_DT,
  M.MSMT_STRT_TM,
  M.MSMT_MIN_VAL,
  M.MSMT_MAX_VAL,
  M.MSMT_AVG_VAL,
  M.MSMT_TOT_VAL,
  M.MSMT_SMPL_CNT,
  M.MSMT_ERR_CNT
 FROM
  BWM.UP_MAP_PROBE B,
  TWG.MSMT M,
  TWG.COMP C
 WHERE
  M.COMP_ID=B.ORIG_COMP_ID AND
  M.COMP_ID=C.COMP_ID AND
  C.COMPTYP_CD in ('BWM_STI','BWM_QOS') 
 ;
      
-- EXPIRE OLD COMPONENTS
update twg.comp c1
set comp_end_dttm = CURRENT timestamp - CURRENT timezone
where
    c1.comptyp_cd in ('BWM_EP','BWM_STI','BWM_QOS')
    ;

 
-- EXPIRE OLD COMPONENTS Attributes
update twg.compattr c2
set compattr_end_dttm = CURRENT timestamp - CURRENT timezone
where
    c2.ATTRTYP_CD in ('BWM_PRT_CONST','BWM_RTT_CONST','BWM_ST_CONST', 'BWM_TASKID', 'BWM_VIRTUAL_HOST')
    ;
