-------------------------------------------------------------------------------
--   OCO Source Materials
--
--   Licensed Materials - Property of IBM
--
--   5724-C02
--
--   (C) Copyright IBM Corp. 2003  All Rights Reserved.
--
--   US Government Users Restricted Rights - Use, duplication or
--   disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
-------------------------------------------------------------------------------
--    File Information: %W%
--    Revision: %I%
--    Date: %G% %U%
-------------------------------------------------------------------------------

-------------------------------------------------------------------------------
-- IY53303 - r.someshwar & jmg(L3)
--
-- Summary of changes:
-- * Using new temp table TEMP_RELNMAP_ID to hold only the essential aggreg.
--   data used to correlate all the aggregate data in staging tables.
--
-- * Moved BWM.STAGE_TR, BWM.STAGE_THRESHOLD, & BWM.STAGE.PATTERN to top
--   before populating TEMP_RELNMAP_ID. (see comments on BWM.STAGE_THRESHOLD)
--
-- * Changed BWM.STAGE_RELATIONMAP, BWM.STAGE_NODE, BWM.STAGE_HOST,
--   BWM.STAGE_APPLICATION, BWM.STAGE_USER, BWM.STAGE_TRANSACTION, &
--   BWM.STAGE_MGMTPOLICY to utilize info from new temp table TEMP_RELNMAP_ID
--   instead of TWG.COMP. (see comments for BWM.STAGE_RELATIONMAP)
--
--  * Because of latter point, we streamlined and got rid of unnecessary extract
--    control and extract logs for the tables above. Now, only entry in
--    BWM.EXTRACT_LOG is for BWM.STAGE_AGGREG_DATA.
--
--  * Moved population of BWM.EXTRACT_LOG to bottom of the process to validate
--    extraction from source was successful.
--------------------------------------------------------------------------------

--*****************************************************************************
-------------------------------------------------------------------------------
-- Extract Aggregate data
-------------------------------------------------------------------------------
--*****************************************************************************

--#IGNORE_ERROR
DROP TABLE TEMP_EXTCONTROL
;

-------------------------------------------------------------------------------
-- create table to hold the extract window
-------------------------------------------------------------------------------
CREATE TABLE TEMP_EXTCONTROL (
  EXTCTL_FROM_INTSEQ  BIGINT,
  EXTCTL_TO_INTSEQ    BIGINT )
;

-------------------------------------------------------------------------------
-- IY53303 - r.someshwar & jmg(L3)
-- create a temporary table to hold all the unique relationmap_ids that are
-- necessary to correlate all the aggregate data
-------------------------------------------------------------------------------
--#IGNORE_ERROR
DROP TABLE TEMP_RELNMAP_ID
;

CREATE TABLE TEMP_RELNMAP_ID (
   RELNMAP_ID DECIMAL(29,0) NOT NULL
);

-------------------------------------------------------------------------------
-- get the from_intseq from the extract_control in the CDW
-------------------------------------------------------------------------------
  
--#INSERT_INTO_SOURCE
INSERT INTO TEMP_EXTCONTROL
SELECT 
  EXTCTL_FROM_INTSEQ,
  -1
FROM 
  TWG.EXTRACT_CONTROL
WHERE
  EXTCTL_SOURCE='AGGREGATEDATA' AND
  EXTCTL_TARGET='BWM.STAGE_AGGREG_DATA' 
;


-------------------------------------------------------------------------------
-- update with the max twh_insert_seq
-- this opens the window if there are new rows in the source
-------------------------------------------------------------------------------
UPDATE TEMP_EXTCONTROL
SET EXTCTL_TO_INTSEQ = (SELECT MAX(AGGREGATE_ID)
			FROM AGGREGATEDATA AG,
                        RELATIONMAP R,
                        MANAGEMENTPOLICY MP
			WHERE
			AG.PARTIAL='0' AND
                        AG.COUNT <> 0 AND
                        R.RELATIONMAP_ID=AG.RELATIONMAP_ID AND
  	                MP.TYPE1 <> 'DISCOVERY' AND
                        R.MGMT_POLICY_OM_ID=MP.UUID1
)
WHERE 0 < (SELECT COUNT(*) FROM AGGREGATEDATA AG,
                        RELATIONMAP R,
                        MANAGEMENTPOLICY MP
	          	WHERE
                        R.RELATIONMAP_ID=AG.RELATIONMAP_ID AND
  	                MP.TYPE1 <> 'DISCOVERY' AND
                        R.MGMT_POLICY_OM_ID=MP.UUID1 AND
			AG.PARTIAL='0' AND
                        AG.COUNT <> 0)
;


-------------------------------------------------------------------------------
-- insert all new node info into the staging twh_cdw
-------------------------------------------------------------------------------

--#INSERT_INTO_TARGET
INSERT INTO BWM.STAGE_AGGREG_DATA  
SELECT 
    AG.THRESH_VIOL_CNT,
    AG.BAD_STATUS_CNT,
    AG.ABORT_STATUS_CNT,
    AG.COUNT,
    AG.AVERAGE_VALUE,
    AG.MAXIMUM_VALUE,
    AG.MINIMUM_VALUE,
    AG.AGGREGATE_ID,
    AG.RELATIONMAP_ID,
    AG.COLL_DATETIME,
    AG.PARTIAL,
    AG.PATT_TRANS_OM_ID,
    AG.COLL_TIME_SPAN
FROM 
  AGGREGATEDATA AG,
  TEMP_EXTCONTROL EC,
  RELATIONMAP R,
  MANAGEMENTPOLICY MP
WHERE
  AG.PARTIAL='0' AND
  AG.COUNT <> 0 AND
  R.RELATIONMAP_ID=AG.RELATIONMAP_ID AND
  MP.TYPE1 <> 'DISCOVERY' AND
  R.MGMT_POLICY_OM_ID=MP.UUID1 AND
  AG.AGGREGATE_ID > EC.EXTCTL_FROM_INTSEQ AND
  AG.AGGREGATE_ID <= EC.EXTCTL_TO_INTSEQ 
;

--*****************************************************************************
-------------------------------------------------------------------------------
-- Extract Pattern data
-------------------------------------------------------------------------------
-------------------------------------------------------------------------------
-- IY53303 - r.someshwar & jmg(L3)
-- * moved up
-- * condition against extract log now based on aggregate ID instead of PT ID
-- insert all new node info into the staging twh_cdw
-------------------------------------------------------------------------------

--#INSERT_INTO_TARGET
INSERT INTO BWM.STAGE_PATTERN  
SELECT 
  PT.UUID1
FROM 
  TEMP_EXTCONTROL EC,
  AGGREGATEDATA AG,
  PT PT,
  RELATIONMAP R,
  MANAGEMENTPOLICY MP
WHERE
  R.RELATIONMAP_ID=AG.RELATIONMAP_ID AND
  MP.TYPE1 <> 'DISCOVERY' AND
  R.MGMT_POLICY_OM_ID=MP.UUID1 AND
  AG.PARTIAL='0' AND
  AG.COUNT <> 0 AND
  AG.PATT_TRANS_OM_ID=PT.UUID1 AND
  AG.AGGREGATE_ID > EC.EXTCTL_FROM_INTSEQ AND
  AG.AGGREGATE_ID <= EC.EXTCTL_TO_INTSEQ 
GROUP BY
  PT.UUID1
;

-------------------------------------------------------------------------------
-- Extract Threshold data
-------------------------------------------------------------------------------
--*****************************************************************************
-------------------------------------------------------------------------------
-- IY53303 - r.someshwar & jmg(L3)
-- * moved up
-- * condition against extract log now based on aggregate ID instead of PT ID
-- insert all new node info into the staging twh_cdw
-------------------------------------------------------------------------------

--#INSERT_INTO_TARGET
INSERT INTO BWM.STAGE_THRESHOLD
SELECT 
  T.UUID1 as UUID1,
  T.THRPTINVERSE_UUID as PATTERN_ID,
  T.THRESHOLDVALUE as THRESHOLDVALUE,
  T.TR_UUID as TR_UUID
FROM 
  THRESHOLD T,
  TEMP_EXTCONTROL EC,
  AGGREGATEDATA AG,
  PT PT, 
  RELATIONMAP R,
  MANAGEMENTPOLICY MP
WHERE
  AG.PARTIAL='0' AND
  AG.COUNT <> 0 AND
  PT.UUID1=AG.PATT_TRANS_OM_ID AND
  PT.UUID1=T.THRPTINVERSE_UUID AND
  R.RELATIONMAP_ID=AG.RELATIONMAP_ID AND
  MP.TYPE1 <> 'DISCOVERY' AND
  R.MGMT_POLICY_OM_ID=MP.UUID1 AND
  AG.AGGREGATE_ID > EC.EXTCTL_FROM_INTSEQ AND
  AG.AGGREGATE_ID <= EC.EXTCTL_TO_INTSEQ 
GROUP BY
  T.UUID1,
  T.THRPTINVERSE_UUID,
  T.THRESHOLDVALUE,
  T.TR_UUID
;


--*****************************************************************************
-------------------------------------------------------------------------------
-- Extract Trigger Response data
-------------------------------------------------------------------------------
--*****************************************************************************
-------------------------------------------------------------------------------
-- IY53303 - r.someshwar & jmg(L3)
-- * moved up
-- * condition against extract log now based on aggregate ID instead of PT ID
-- insert all new node info into the staging twh_cdw
-------------------------------------------------------------------------------

--#INSERT_INTO_TARGET
INSERT INTO BWM.STAGE_TR 
SELECT 
  TR.UUID1 as UUID1,
  TR.MANAGEMENTPOLICYID as MGMT_POLICY_ID,
  TR.RESPONSELEVEL as RESPONSELEVEL
FROM 
  TEMP_EXTCONTROL EC,
  AGGREGATEDATA AG,
  PT PT,
  THRESHOLD T,
  TR TR, 
  RELATIONMAP R,
  MANAGEMENTPOLICY MP
WHERE
  AG.PARTIAL='0' AND
  AG.COUNT <> 0 AND
  PT.UUID1=AG.PATT_TRANS_OM_ID AND
  PT.UUID1=T.THRPTINVERSE_UUID AND
  T.TR_UUID=TR.UUID1 AND
  R.RELATIONMAP_ID=AG.RELATIONMAP_ID AND
  MP.TYPE1 <> 'DISCOVERY' AND
  R.MGMT_POLICY_OM_ID=MP.UUID1 AND
  AG.AGGREGATE_ID > EC.EXTCTL_FROM_INTSEQ AND
  AG.AGGREGATE_ID <= EC.EXTCTL_TO_INTSEQ 
GROUP BY
  TR.UUID1,
  TR.MANAGEMENTPOLICYID,
  TR.RESPONSELEVEL
;

-------------------------------------------------------------------------------
-- insert all the unique relationmap_id for the aggregate data being brought
-- into the warehouse.
-------------------------------------------------------------------------------
--------------------------------------------------------------------------------
-- IY53303 - r.someshwar & jmg(L3)
-- * Inserting all aggregated data used for correlations in the following
--   staging tables
--------------------------------------------------------------------------------
INSERT INTO TEMP_RELNMAP_ID
SELECT
   AG.RELATIONMAP_ID
FROM 
  AGGREGATEDATA AG,
  TEMP_EXTCONTROL EC,
  RELATIONMAP R,
  MANAGEMENTPOLICY MP
WHERE
  AG.PARTIAL='0' AND
  AG.COUNT <> 0 AND
  R.RELATIONMAP_ID=AG.RELATIONMAP_ID AND
  MP.TYPE1 <> 'DISCOVERY' AND
  R.MGMT_POLICY_OM_ID=MP.UUID1 AND
  AG.AGGREGATE_ID > EC.EXTCTL_FROM_INTSEQ AND
  AG.AGGREGATE_ID <= EC.EXTCTL_TO_INTSEQ 
GROUP BY
  AG.RELATIONMAP_ID
;
-------------------------------------------------------------------------------
--  drop to_intseq temp table in CDW
-------------------------------------------------------------------------------

--#EXECUTE_AT_TARGET
--#IGNORE_ERROR          
DROP TABLE BWM.TEMP_TO_INTSEQ
;

-------------------------------------------------------------------------------
-- create to_intseq temp table in CDW
-------------------------------------------------------------------------------

--#EXECUTE_AT_TARGET
CREATE TABLE BWM.TEMP_TO_INTSEQ (
  EXTCTL_TO_INTSEQ   BIGINT ) 
;

-------------------------------------------------------------------------------
-- copy to_intseq value into temp table in CDW
-------------------------------------------------------------------------------

--#INSERT_INTO_TARGET
INSERT INTO BWM.TEMP_TO_INTSEQ 
SELECT EXTCTL_TO_INTSEQ FROM TEMP_EXTCONTROL
;


-------------------------------------------------------------------------------
-- update extract control with to_intseq value
-------------------------------------------------------------------------------
--#EXECUTE_AT_TARGET
UPDATE TWG.EXTRACT_CONTROL
SET EXTCTL_TO_INTSEQ = (SELECT EXTCTL_TO_INTSEQ FROM BWM.TEMP_TO_INTSEQ)
WHERE
  EXTCTL_SOURCE='AGGREGATEDATA' AND
  EXTCTL_TARGET='BWM.STAGE_AGGREG_DATA'
;


-------------------------------------------------------------------------------
-- insert all new node info into the staging twh_cdw
-------------------------------------------------------------------------------
-------------------------------------------------------------------------------
-- IY53303 - r.someshwar & jmg(L3)
-- * Correlation based on TEMP_RELNMAP_ID and removed extraneous correlations
-- * Removed unnecessary updates to extract log and extract control
-- insert all new node info into the staging twh_cdw
-------------------------------------------------------------------------------

--#INSERT_INTO_TARGET
INSERT INTO BWM.STAGE_RELATIONMAP  
SELECT 
  R.RELATIONMAP_ID,        
  R.MGMT_POLICY_OM_ID,
  R.PARENT_NODE_ID,
  R.CURRENT_NODE_ID,
  R.ROOT_NODE_ID,
  R.RELATED_NODE_ID 
FROM 
  RELATIONMAP R,
  TEMP_RELNMAP_ID TR
WHERE
  R.RELATIONMAP_ID=TR.RELNMAP_ID
GROUP BY
  R.RELATIONMAP_ID,        
  R.MGMT_POLICY_OM_ID,
  R.PARENT_NODE_ID,
  R.CURRENT_NODE_ID,
  R.ROOT_NODE_ID,
  R.RELATED_NODE_ID
;

-------------------------------------------------------------------------------
-- insert all new node info into the staging twh_cdw
-------------------------------------------------------------------------------
-------------------------------------------------------------------------------
-- IY53303 - r.someshwar & jmg(L3)
-- * Correlation based on TEMP_RELNMAP_ID and removed extraneous correlations
-- * Removed unnecessary updates to extract log and extract control
-- insert all new node info into the staging twh_cdw
-------------------------------------------------------------------------------
--#INSERT_INTO_TARGET
INSERT INTO BWM.STAGE_NODE  
SELECT 
  N.NODE_ID,
  N.APPL_ID,
  N.TX_ID,
  N.USER_ID,                     
  N.HOST_ID,
  N.NODE_SEQUENCE
FROM 
  NODE N,
  RELATIONMAP R,
  TEMP_RELNMAP_ID TR
WHERE
  R.RELATIONMAP_ID=TR.RELNMAP_ID AND
  R.CURRENT_NODE_ID=N.NODE_ID
GROUP BY
  N.NODE_ID,
  N.APPL_ID,
  N.TX_ID,
  N.USER_ID,                     
  N.HOST_ID,
  N.NODE_SEQUENCE
;

-------------------------------------------------------------------------------
-- insert all new host info into the staging twh_cdw
-------------------------------------------------------------------------------
-------------------------------------------------------------------------------
-- IY53303 - r.someshwar & jmg(L3)
-- * Correlation based on TEMP_RELNMAP_ID and removed extraneous correlations
-- * Removed unnecessary updates to extract log and extract control
-- insert all new node info into the staging twh_cdw
-------------------------------------------------------------------------------

--#INSERT_INTO_TARGET
INSERT INTO BWM.STAGE_HOST  
SELECT 
  H.HOST_ID,
  H.HOST_NAME,
  H.HOST_IP_ADDRESS
FROM 
  HOST H,
  NODE N,
  RELATIONMAP R,
  TEMP_RELNMAP_ID TR
 WHERE
  R.RELATIONMAP_ID=TR.RELNMAP_ID AND
  R.CURRENT_NODE_ID=N.NODE_ID AND
  N.HOST_ID=H.HOST_ID
GROUP BY
  H.HOST_ID,
  H.HOST_NAME,
  H.HOST_IP_ADDRESS
;

-------------------------------------------------------------------------------
-- insert all new application info into the staging twh_cdw
-------------------------------------------------------------------------------
-------------------------------------------------------------------------------
-- IY53303 - r.someshwar & jmg(L3)
-- * Correlation based on TEMP_RELNMAP_ID and removed extraneous correlations
-- * Removed unnecessary updates to extract log and extract control
-- insert all new node info into the staging twh_cdw
-------------------------------------------------------------------------------

--#INSERT_INTO_TARGET
INSERT INTO BWM.STAGE_APPLICATION  
SELECT
  A.APPL_NAME, 
  A.APPL_ID
FROM 
  APPLICATION A,
  NODE N,
  RELATIONMAP R,
  TEMP_RELNMAP_ID TR
WHERE
  R.RELATIONMAP_ID=TR.RELNMAP_ID AND
  R.CURRENT_NODE_ID=N.NODE_ID AND
  N.APPL_ID=A.APPL_ID
GROUP BY
  A.APPL_NAME, 
  A.APPL_ID
;

-------------------------------------------------------------------------------
-- insert all new user info into the staging twh_cdw
-------------------------------------------------------------------------------
-------------------------------------------------------------------------------
-- IY53303 - r.someshwar & jmg(L3)
-- * Correlation based on TEMP_RELNMAP_ID and removed extraneous correlations
-- * Removed unnecessary updates to extract log and extract control
-- insert all new node info into the staging twh_cdw
-------------------------------------------------------------------------------

--#INSERT_INTO_TARGET
INSERT INTO BWM.STAGE_USER  
SELECT 
  U.USER_ID,
  U.USER_NAME
FROM 
  ARM_USER U,
  NODE N,
  RELATIONMAP R,
  TEMP_RELNMAP_ID TR
WHERE
  R.RELATIONMAP_ID=TR.RELNMAP_ID AND
  R.CURRENT_NODE_ID=N.NODE_ID AND
  N.USER_ID=U.USER_ID
GROUP BY
  U.USER_ID,
  U.USER_NAME
;


-------------------------------------------------------------------------------
-- insert all new transaction info into the staging twh_cdw
-------------------------------------------------------------------------------
-------------------------------------------------------------------------------
-- IY53303 - r.someshwar & jmg(L3)
-- * Correlation based on TEMP_RELNMAP_ID and removed extraneous correlations
-- * Removed unnecessary updates to extract log and extract control
-- insert all new node info into the staging twh_cdw
-------------------------------------------------------------------------------

--#INSERT_INTO_TARGET
INSERT INTO BWM.STAGE_TRANSACTION  
SELECT 
  T.TX_DESC,
  T.TX_NAME,
  T.TX_ID
FROM 
  TRANSACTION T,
  NODE N,
  RELATIONMAP R,
  TEMP_RELNMAP_ID TR
WHERE
  R.RELATIONMAP_ID=TR.RELNMAP_ID AND
  R.CURRENT_NODE_ID=N.NODE_ID AND
  T.TX_ID=N.TX_ID 
GROUP BY
  T.TX_DESC,
  T.TX_NAME,
  T.TX_ID
;

-------------------------------------------------------------------------------
-- insert all new node info into the staging twh_cdw
-------------------------------------------------------------------------------
-------------------------------------------------------------------------------
-- IY53303 - r.someshwar & jmg(L3)
-- * Correlation based on TEMP_RELNMAP_ID and removed extraneous correlations
-- * Removed unnecessary updates to extract log and extract control
-- insert all new node info into the staging twh_cdw
-------------------------------------------------------------------------------

--#INSERT_INTO_TARGET
INSERT INTO BWM.STAGE_MGMTPOLICY  
SELECT 
  MP.NAME,
  MP.OBJECTVERSION,
  MP.CREATOR,
  MP.CREATED,
  MP.DELETED,
  MP.DELETOR,
  MP.LASTUPDATED,
  MP.UPDATOR,
  MP.DESCRIPTION,
  MP.UUID1,
  MP.ISDELETE,
  MP.TYPE1,
  MP.STATE1,
  MP.EDGEPOLICY_UUID,
  MP.SCHEDULE_UUID,
  MP.ENDPOINTGROUP_UUID
FROM 
  MANAGEMENTPOLICY MP,
  RELATIONMAP R,
  TEMP_RELNMAP_ID TR
WHERE
  R.RELATIONMAP_ID=TR.RELNMAP_ID AND
  R.MGMT_POLICY_OM_ID=MP.UUID1
GROUP BY
  MP.NAME,
  MP.OBJECTVERSION,
  MP.CREATOR,
  MP.CREATED,
  MP.DELETED,
  MP.DELETOR,
  MP.LASTUPDATED,
  MP.UPDATOR,
  MP.DESCRIPTION,
  MP.UUID1,
  MP.ISDELETE,
  MP.TYPE1,
  MP.STATE1,
  MP.EDGEPOLICY_UUID,
  MP.SCHEDULE_UUID,
  MP.ENDPOINTGROUP_UUID
;

-------------------------------------------------------------------------------
-- write extract info to extract log
-- this fires the trigger that updates extract control to close the window
-------------------------------------------------------------------------------
-------------------------------------------------------------------------------
-- IY53303 - r.someshwar & jmg(L3)
--  * Moved population of BWM.EXTRACT_LOG to bottom of the process to validate
--    extraction from source was successful.
-------------------------------------------------------------------------------
--#EXECUTE_AT_TARGET
INSERT INTO TWG.EXTRACT_LOG (
    EXTLOG_SOURCE, 
    EXTLOG_TARGET, 
    EXTLOG_DONE_DTTM, 
    EXTLOG_FROM_RAWSEQ, 
    EXTLOG_TO_RAWSEQ, 
    EXTLOG_FROM_INTSEQ,
    EXTLOG_TO_INTSEQ,
    EXTLOG_FROM_DTTM,
    EXTLOG_TO_DTTM )
SELECT
  EC.EXTCTL_SOURCE AS EXTLOG_SOURCE,
  EC.EXTCTL_TARGET AS EXTLOG_TARGET,
  CURRENT TIMESTAMP - CURRENT TIMEZONE AS EXTLOG_DONE_DTTM,
  EC.EXTCTL_FROM_RAWSEQ AS EXTLOG_FROM_RAWSEQ,
  EC.EXTCTL_TO_RAWSEQ AS EXTLOG_TO_RAWSEQ,
  EC.EXTCTL_FROM_INTSEQ AS EXTLOG_FROM_INTSEQ,
  EC.EXTCTL_TO_INTSEQ AS EXTLOG_TO_INTSEQ,
  EC.EXTCTL_FROM_DTTM AS EXTLOG_FROM_DTTM,
  EC.EXTCTL_TO_DTTM AS EXTLOG_TO_DTTM
FROM 
  TWG.EXTRACT_CONTROL EC
WHERE
  EC.EXTCTL_SOURCE = 'AGGREGATEDATA' AND
  EC.EXTCTL_TARGET = 'BWM.STAGE_AGGREG_DATA'
;

--*****************************************************************************
