-------------------------------------------------------------------------------
--   OCO Source Materials
--
--   Licensed Materials - Property of IBM
--
--   5724-C02
--
--   (C) Copyright IBM Corp. 2003  All Rights Reserved.
--
--   US Government Users Restricted Rights - Use, duplication or
--   disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
-------------------------------------------------------------------------------
--    File Information: %W%
--    Revision: %I%
--    Date: %G% %U%
-------------------------------------------------------------------------------
--------------------------------------------------------------------------
-- D127604 - j.griffith
-- All instances in the FROM statements of COMP, COMPRELN, and MSMT_TYP
-- changed to CUR_ to avoid duplicates
--------------------------------------------------------------------------
-- etl2

-- extract step - populate "translation" dimension tables
-- and stage fact table
-- translation dimension tables are used to track ids from the
-- original cdw into the star schema so you can tell where the data
-- actually came from when looking at a star schema.  star schemas
-- re-assign ids so that data from various cdws use the same ids for
-- the same thing.  remember that the translatoin dimension tables
-- are "permanent" and the stage fact table is dropped and recreated
-- each time (in the pre-extract step in fact).

-- this script is "re-written" multiple times by the java program that
-- runs execsql - once for each cdw where data is extracted.

-- get the high value for the window

--#VERSION 1.1.0.1.0
--------------------------------------------------------------------------
-- D127604 - j.griffith
-- Clear out T-tables
--------------------------------------------------------------------------

--#EXECUTE_AT_TARGET
DELETE FROM BWM.T_HOST;
--#EXECUTE_AT_TARGET
DELETE FROM BWM.T_APP;
--#EXECUTE_AT_TARGET
DELETE FROM BWM.T_TX;
--#EXECUTE_AT_TARGET
DELETE FROM BWM.T_TX_ND;
--#EXECUTE_AT_TARGET
DELETE FROM BWM.T_TX_ND_METRIC;
--#EXECUTE_AT_TARGET
DELETE FROM BWM.T_TX;

------------------------
-- HOST
------------------------
UPDATE TWG.EXTRACT_CONTROL
 SET EXTCTL_TO_INTSEQ=(SELECT MAX_VALUE FROM BWM.VE_HOST)
 WHERE
  EXTCTL_SOURCE='TWG.COMP' AND EXTCTL_TARGET='BWM.T_HOST' AND
  EXISTS (SELECT MAX_VALUE FROM BWM.VE_HOST)
    ;

--#INSERT_INTO_TARGET
INSERT INTO BWM.T_HOST (
    CDW_ID,
    HOST_ID,
    ORIG_HOST_ID,
    HOST_NM,
    IP_ADDRESS,
    CUST_NM,
    CENTER_NM)
 SELECT
  1,
  0,
  A.ORIG_HOST_ID,
  A.HOST_NM,
  A.LAST_IP_ADDRESS,
  A.CUST_NM,
  A.CENTR_NM
 FROM
  BWM.VD_HOST A,
  TWG.EXTRACT_CONTROL EC
 WHERE
  EC.EXTCTL_SOURCE='TWG.COMP' AND
  EC.EXTCTL_TARGET='BWM.T_HOST' AND
  A.ORIG_HOST_ID>EC.EXTCTL_FROM_INTSEQ AND
  A.ORIG_HOST_ID<=EC.EXTCTL_TO_INTSEQ
;

INSERT INTO TWG.EXTRACT_LOG
 SELECT
  EC.EXTCTL_SOURCE AS EXTLOG_SOURCE,
  EC.EXTCTL_TARGET AS EXTLOG_TARGET,
  CURRENT TIMESTAMP AS EXTLOG_DONE_DTTM,
  EC.EXTCTL_FROM_RAWSEQ AS EXTLOG_FROM_RAWSEQ,
  EC.EXTCTL_TO_RAWSEQ AS EXTLOG_TO_RAWSEQ,
  EC.EXTCTL_FROM_INTSEQ AS EXTLOG_FROM_INTSEQ,
  EC.EXTCTL_TO_INTSEQ AS EXTLOG_TO_INTSEQ,
  EC.EXTCTL_FROM_DTTM AS EXTLOG_FROM_DTTM,
  EC.EXTCTL_TO_DTTM AS EXTLOG_TO_DTTM
 FROM
  TWG.EXTRACT_CONTROL EC
 WHERE
  EC.EXTCTL_SOURCE='TWG.COMP' AND
  EC.EXTCTL_TARGET='BWM.T_HOST'
;

------------------------
--  FROM BWM.STG_D_APP to BWM.T_APP
------------------------
UPDATE TWG.EXTRACT_CONTROL
 SET EXTCTL_TO_INTSEQ=(SELECT MAX_VALUE FROM BWM.VE_APP)
 WHERE
  EXTCTL_SOURCE='TWG.COMP' AND EXTCTL_TARGET='BWM.T_APP' AND
  EXISTS (SELECT MAX_VALUE FROM BWM.VE_APP)
    ;

--#INSERT_INTO_TARGET
INSERT INTO BWM.T_APP (
    CDW_ID,
    APP_ID,
    ORIG_APP_ID,
    J2EESERVER_NAME,
    J2EE_CELL_NAME,
    J2EE_DOMAIN,
    J2EE_NODE,
    J2EE_TYPE_VER,
    PROBE_HOST,
    PROBE_NAME)
 SELECT
  1,
  0,
  A.ORIG_APP_ID,
  A.J2EESERVER_NAME,
  A.J2EE_CELL_NAME,
  A.J2EE_DOMAIN,
  A.J2EE_NODE,
  A.J2EE_TYPE_VER,
  A.PROBE_HOST,
  A.PROBE_NAME
 FROM
  BWM.STG_D_APP A,
  TWG.EXTRACT_CONTROL EC
 WHERE
  EC.EXTCTL_SOURCE='TWG.COMP' AND
  EC.EXTCTL_TARGET='BWM.T_APP' AND
  A.ORIG_APP_ID>EC.EXTCTL_FROM_INTSEQ AND
  A.ORIG_APP_ID<=EC.EXTCTL_TO_INTSEQ
;

INSERT INTO TWG.EXTRACT_LOG
 SELECT
  EC.EXTCTL_SOURCE AS EXTLOG_SOURCE,
  EC.EXTCTL_TARGET AS EXTLOG_TARGET,
  CURRENT TIMESTAMP AS EXTLOG_DONE_DTTM,
  EC.EXTCTL_FROM_RAWSEQ AS EXTLOG_FROM_RAWSEQ,
  EC.EXTCTL_TO_RAWSEQ AS EXTLOG_TO_RAWSEQ,
  EC.EXTCTL_FROM_INTSEQ AS EXTLOG_FROM_INTSEQ,
  EC.EXTCTL_TO_INTSEQ AS EXTLOG_TO_INTSEQ,
  EC.EXTCTL_FROM_DTTM AS EXTLOG_FROM_DTTM,
  EC.EXTCTL_TO_DTTM AS EXTLOG_TO_DTTM
 FROM
  TWG.EXTRACT_CONTROL EC
 WHERE
  EC.EXTCTL_SOURCE='TWG.COMP' AND
  EC.EXTCTL_TARGET='BWM.T_APP'
;

------------------------
-- TX
------------------------
UPDATE TWG.EXTRACT_CONTROL
 SET EXTCTL_TO_INTSEQ=(SELECT MAX_VALUE FROM BWM.VE_TX)
 WHERE
  EXTCTL_SOURCE='TWG.COMP' AND EXTCTL_TARGET='BWM.T_TX' AND
  EXISTS (SELECT MAX_VALUE FROM BWM.VE_TX)
    ;

--#INSERT_INTO_TARGET
INSERT INTO BWM.T_TX (
    CDW_ID,
    TX_ID,
    ORIG_TX_ID,
    TX_NAME,
    TX_DESC,
    URL_PROTOCOL,
    WEBSITE,
    WEBSITE_PATH,
    WEBSITE_QUERY)
 SELECT
  1,
  0,
  A.ORIG_TX_ID,
  A.TX_NAME,
  A.TX_DESCRIPTION,
  A.URL_PROTOCOL,
  A.WEBSITE,
  A.WEBSITE_PATH,
  A.WEBSITE_QUERY
 FROM
  BWM.VD_TX A,
  TWG.EXTRACT_CONTROL EC
 WHERE
  EC.EXTCTL_SOURCE='TWG.COMP' AND
  EC.EXTCTL_TARGET='BWM.T_TX' AND
  A.ORIG_TX_ID>EC.EXTCTL_FROM_INTSEQ AND
  A.ORIG_TX_ID<=EC.EXTCTL_TO_INTSEQ
;

INSERT INTO TWG.EXTRACT_LOG
 SELECT
  EC.EXTCTL_SOURCE AS EXTLOG_SOURCE,
  EC.EXTCTL_TARGET AS EXTLOG_TARGET,
  CURRENT TIMESTAMP AS EXTLOG_DONE_DTTM,
  EC.EXTCTL_FROM_RAWSEQ AS EXTLOG_FROM_RAWSEQ,
  EC.EXTCTL_TO_RAWSEQ AS EXTLOG_TO_RAWSEQ,
  EC.EXTCTL_FROM_INTSEQ AS EXTLOG_FROM_INTSEQ,
  EC.EXTCTL_TO_INTSEQ AS EXTLOG_TO_INTSEQ,
  EC.EXTCTL_FROM_DTTM AS EXTLOG_FROM_DTTM,
  EC.EXTCTL_TO_DTTM AS EXTLOG_TO_DTTM
 FROM
  TWG.EXTRACT_CONTROL EC
 WHERE
  EC.EXTCTL_SOURCE='TWG.COMP' AND
  EC.EXTCTL_TARGET='BWM.T_TX'
;


---------------------------
-- BWM_TX_ND_MET
---------------------------
UPDATE TWG.EXTRACT_CONTROL
 SET EXTCTL_TO_INTSEQ=(SELECT MAX_VALUE FROM BWM.VE_TX_ND_MET)
 WHERE
  EXTCTL_SOURCE='BWM.STG_TX_ND_MET' AND EXTCTL_TARGET='BWM.T_TX_ND_METRIC' AND
  EXISTS (SELECT MAX_VALUE FROM BWM.VE_TX_ND_MET)
    ;

--#INSERT_INTO_TARGET
INSERT INTO BWM.T_TX_ND_METRIC (
    CDW_ID,
    METRIC_ID,
    ORIG_METRIC_ID,
    MET_CATEGORY,
    MET_DESC,
    MET_NAME,
    MET_UNITS,
    MIN_EXISTS,
    MAX_EXISTS,
    AVG_EXISTS,
    TOTAL_EXISTS,
    MSRC_NM)
 SELECT
  1,
  0,
  A.ORIG_METRIC_ID,
  A.MET_CATEGORY,
  A.MET_DESC,
  A.MET_NAME,
  A.MET_UNITS,
  A.MIN_EXISTS,
  A.MAX_EXISTS,
  A.AVG_EXISTS,
  A.TOTAL_EXISTS,
  A.MSRC_NM
 FROM
  BWM.VD_TX_ND_MET A,
  TWG.EXTRACT_CONTROL EC
 WHERE
  EC.EXTCTL_SOURCE='BWM.STG_TX_ND_MET' AND
  EC.EXTCTL_TARGET='BWM.T_TX_ND_METRIC' AND
  A.ORIG_METRIC_ID>EC.EXTCTL_FROM_INTSEQ AND
  A.ORIG_METRIC_ID<=EC.EXTCTL_TO_INTSEQ  AND
  A.MET_NAME <> 'Response Time'
;

--#INSERT_INTO_TARGET
INSERT INTO BWM.T_TX_ND_METRIC (
    CDW_ID,
    METRIC_ID,
    ORIG_METRIC_ID,
    MET_CATEGORY,
    MET_DESC,
    MET_NAME,
    MET_UNITS,
    MIN_EXISTS,
    MAX_EXISTS,
    AVG_EXISTS,
    TOTAL_EXISTS,
    MSRC_NM)
 SELECT
  1,
  0,
  A.ORIG_METRIC_ID,
  A.MET_CATEGORY,
  A.MET_DESC,
  A.MET_NAME,
  'Sec',
  A.MIN_EXISTS,
  A.MAX_EXISTS,
  A.AVG_EXISTS,
  A.TOTAL_EXISTS,
  A.MSRC_NM
 FROM
  BWM.VD_TX_ND_MET A,
  TWG.EXTRACT_CONTROL EC
 WHERE
  EC.EXTCTL_SOURCE='BWM.STG_TX_ND_MET' AND
  EC.EXTCTL_TARGET='BWM.T_TX_ND_METRIC' AND
  A.ORIG_METRIC_ID>EC.EXTCTL_FROM_INTSEQ AND
  A.ORIG_METRIC_ID<=EC.EXTCTL_TO_INTSEQ  AND
  A.MET_NAME = 'Response Time'
;

INSERT INTO TWG.EXTRACT_LOG
 SELECT
  EC.EXTCTL_SOURCE AS EXTLOG_SOURCE,
  EC.EXTCTL_TARGET AS EXTLOG_TARGET,
  CURRENT TIMESTAMP AS EXTLOG_DONE_DTTM,
  EC.EXTCTL_FROM_RAWSEQ AS EXTLOG_FROM_RAWSEQ,
  EC.EXTCTL_TO_RAWSEQ AS EXTLOG_TO_RAWSEQ,
  EC.EXTCTL_FROM_INTSEQ AS EXTLOG_FROM_INTSEQ,
  EC.EXTCTL_TO_INTSEQ AS EXTLOG_TO_INTSEQ,
  EC.EXTCTL_FROM_DTTM AS EXTLOG_FROM_DTTM,
  EC.EXTCTL_TO_DTTM AS EXTLOG_TO_DTTM
 FROM
  TWG.EXTRACT_CONTROL EC
 WHERE
  EC.EXTCTL_SOURCE='BWM.STG_TX_ND_MET' AND
  EC.EXTCTL_TARGET='BWM.T_TX_ND_METRIC'
;


---------------------------------------
-- FROM BWM.STG_D_TX_ND TO BWM.T_TX_ND
---------------------------------------

UPDATE TWG.EXTRACT_CONTROL
 SET EXTCTL_TO_INTSEQ=(SELECT MAX_VALUE FROM BWM.VE_TX_ND)
 WHERE
  EXTCTL_SOURCE='TWG.COMP' AND EXTCTL_TARGET='BWM.T_TX_ND' AND
  EXISTS (SELECT MAX_VALUE FROM BWM.VE_TX_ND)
    ;

--#INSERT_INTO_TARGET
INSERT INTO BWM.T_TX_ND (
    CDW_ID,
    TX_ND_ID,
    ORIG_TX_ND_ID,
    TX_ND_NAME,
    MANAGEMENT_POLICY,
    INVOKING_USER,
    ROOT_CDW_ID,
    PARENT_CDW_ID)
 SELECT
  1,
  0,
  A.ORIG_TX_ND_ID,
  A.TX_ND_NAME,
  A.MANAGEMENT_POLICY,
  A.INVOKING_USER,
  A.ROOT_CDW_ID,
  A.PARENT_CDW_ID
 FROM
  BWM.STG_D_TX_ND A,
  TWG.EXTRACT_CONTROL EC
 WHERE
  EC.EXTCTL_SOURCE='TWG.COMP' AND
  EC.EXTCTL_TARGET='BWM.T_TX_ND' AND
  A.ORIG_TX_ND_ID>EC.EXTCTL_FROM_INTSEQ AND
  A.ORIG_TX_ND_ID<=EC.EXTCTL_TO_INTSEQ
;

INSERT INTO TWG.EXTRACT_LOG
 SELECT
  EC.EXTCTL_SOURCE AS EXTLOG_SOURCE,
  EC.EXTCTL_TARGET AS EXTLOG_TARGET,
  CURRENT TIMESTAMP AS EXTLOG_DONE_DTTM,
  EC.EXTCTL_FROM_RAWSEQ AS EXTLOG_FROM_RAWSEQ,
  EC.EXTCTL_TO_RAWSEQ AS EXTLOG_TO_RAWSEQ,
  EC.EXTCTL_FROM_INTSEQ AS EXTLOG_FROM_INTSEQ,
  EC.EXTCTL_TO_INTSEQ AS EXTLOG_TO_INTSEQ,
  EC.EXTCTL_FROM_DTTM AS EXTLOG_FROM_DTTM,
  EC.EXTCTL_TO_DTTM AS EXTLOG_TO_DTTM
 FROM
  TWG.EXTRACT_CONTROL EC
 WHERE
  EC.EXTCTL_SOURCE='TWG.COMP' AND
  EC.EXTCTL_TARGET='BWM.T_TX_ND'
;

----------------------------------------
--  FROM STG_F_TX_ND_HR TO STG1_TX_ND_HR
----------------------------------------

-- FROM TWG.MSMT TO BWM.STG1_TX_ND_HR

UPDATE TWG.EXTRACT_CONTROL
 SET EXTCTL_TO_INTSEQ=(SELECT MAX_VALUE FROM BWM.VE_STG_TX_ND_HR)
 WHERE
  EXTCTL_SOURCE='TWG.MSMT' AND EXTCTL_TARGET='BWM.STG1_TX_ND_HR' AND
  EXISTS (SELECT MAX_VALUE FROM BWM.VE_STG_TX_ND_HR)
    ;

--#INSERT_INTO_TARGET
INSERT INTO BWM.STG1_TX_ND_HR (
    CDW_ID,
    ORIG_TX_ND_ID,
    ORIG_TX_ID,
    ORIG_APP_ID,
    ORIG_HOST_ID,
    ORIG_METRIC_ID,
    MEAS_HOUR,
    MIN_VALUE,
    MAX_VALUE,
    AVG_VALUE,
    TOTAL_VALUE,
    SAMPLE_COUNT,
    ERROR_COUNT)
 SELECT
  1,
  A.ORIG_TX_ND_ID,
  A.ORIG_TX_ID,
  A.ORIG_APP_ID,
  A.ORIG_HOST_ID,
  A.ORIG_METRIC_ID,
  A.MEAS_HOUR,
  A.MIN_VALUE,
  A.MAX_VALUE,
  A.AVG_VALUE,
  A.TOTAL_VALUE,
  A.SAMPLE_COUNT,
  A.ERROR_COUNT
 FROM
  BWM.STG_CDW_TX_ND_HR A,
  TWG.EXTRACT_CONTROL EC
 WHERE
  EC.EXTCTL_SOURCE='TWG.MSMT' AND
  EC.EXTCTL_TARGET='BWM.STG1_TX_ND_HR' AND
  A.MSMT_ID>EC.EXTCTL_FROM_INTSEQ AND
  A.MSMT_ID<=EC.EXTCTL_TO_INTSEQ
;




INSERT INTO TWG.EXTRACT_LOG
 SELECT
  EC.EXTCTL_SOURCE AS EXTLOG_SOURCE,
  EC.EXTCTL_TARGET AS EXTLOG_TARGET,
  CURRENT TIMESTAMP AS EXTLOG_DONE_DTTM,
  EC.EXTCTL_FROM_RAWSEQ AS EXTLOG_FROM_RAWSEQ,
  EC.EXTCTL_TO_RAWSEQ AS EXTLOG_TO_RAWSEQ,
  EC.EXTCTL_FROM_INTSEQ AS EXTLOG_FROM_INTSEQ,
  EC.EXTCTL_TO_INTSEQ AS EXTLOG_TO_INTSEQ,
  EC.EXTCTL_FROM_DTTM AS EXTLOG_FROM_DTTM,
  EC.EXTCTL_TO_DTTM AS EXTLOG_TO_DTTM
 FROM
  TWG.EXTRACT_CONTROL EC
 WHERE
  EC.EXTCTL_SOURCE='TWG.MSMT' AND
  EC.EXTCTL_TARGET='BWM.STG1_TX_ND_HR'
;

--SELECT * FROM BWM.STG1_TX_ND_HR;

declare global temporary table NULL_VAL (
    VAL INTEGER
    )
with replace on commit preserve rows not logged;

insert into session.NULL_VAL(VAL) values(null);

----------------------------------------
--  FROM STG_F_TX_ND_HR TO STG2_TX_ND_HR
----------------------------------------

UPDATE TWG.EXTRACT_CONTROL
 SET EXTCTL_TO_INTSEQ=(SELECT MAX_VALUE FROM BWM.VE_STG_TX_ND_HR)
 WHERE
  EXTCTL_SOURCE='TWG.MSMT' AND EXTCTL_TARGET='BWM.STG2_TX_ND_HR' AND
  EXISTS (SELECT MAX_VALUE FROM BWM.VE_STG_TX_ND_HR)
    ;

--#INSERT_INTO_TARGET
INSERT INTO BWM.STG2_TX_ND_HR (
    CDW_ID,
    ORIG_TX_ND_ID,
    ORIG_TX_ID,
    ORIG_APP_ID,
    ORIG_HOST_ID,
    ORIG_METRIC_ID,
    MEAS_HOUR,
    MIN_VALUE,
    MAX_VALUE,
    AVG_VALUE,
    TOTAL_VALUE,
    SAMPLE_COUNT,
    ERROR_COUNT)
 SELECT
  1,
  A.ORIG_TX_ND_ID,
  MIN(A.ORIG_TX_ID),
  MIN(A.ORIG_APP_ID),
  MIN(A.ORIG_HOST_ID),
  0-INTEGER(SUBSTR(CA.ATTRTYP_CD,15,1)) as ORIG_METRIC_ID,
  A.MEAS_HOUR,
  V.VAL,
  MIN(INTEGER(CA.COMPATTR_VAL)),
  V.VAL,
  V.VAL,
  V.VAL,
  V.VAL
 FROM
  BWM.STG_CDW_TX_ND_HR A,
  TWG.EXTRACT_CONTROL EC,
  TWG.CUR_COMPATTR CA,
  TWG.MSMTTYP MT,
  SESSION.NULL_VAL V
 WHERE
  EC.EXTCTL_SOURCE='TWG.MSMT' AND
  EC.EXTCTL_TARGET='BWM.STG2_TX_ND_HR' AND
  A.MSMT_ID>EC.EXTCTL_FROM_INTSEQ AND
  A.MSMT_ID<=EC.EXTCTL_TO_INTSEQ AND
  A.ORIG_TX_ND_ID=CA.COMP_ID AND
  CA.ATTRTYP_CD LIKE 'BWM_THRESHOLD_%' AND
  A.ORIG_METRIC_ID=MT.MSMTTYP_ID AND
  MT.MSMTTYP_NM IN ('Response Time','Round Trip Time','Service Time','Page Render Time')
 GROUP BY
  A.MEAS_HOUR,A.ORIG_TX_ND_ID,CA.ATTRTYP_CD, V.VAL
;

--SELECT * FROM BWM.STG2_TX_ND_HR;

INSERT INTO TWG.EXTRACT_LOG
 SELECT
  EC.EXTCTL_SOURCE AS EXTLOG_SOURCE,
  EC.EXTCTL_TARGET AS EXTLOG_TARGET,
  CURRENT TIMESTAMP AS EXTLOG_DONE_DTTM,
  EC.EXTCTL_FROM_RAWSEQ AS EXTLOG_FROM_RAWSEQ,
  EC.EXTCTL_TO_RAWSEQ AS EXTLOG_TO_RAWSEQ,
  EC.EXTCTL_FROM_INTSEQ AS EXTLOG_FROM_INTSEQ,
  EC.EXTCTL_TO_INTSEQ AS EXTLOG_TO_INTSEQ,
  EC.EXTCTL_FROM_DTTM AS EXTLOG_FROM_DTTM,
  EC.EXTCTL_TO_DTTM AS EXTLOG_TO_DTTM
 FROM
  TWG.EXTRACT_CONTROL EC
 WHERE
  EC.EXTCTL_SOURCE='TWG.MSMT' AND
  EC.EXTCTL_TARGET='BWM.STG2_TX_ND_HR'
;

--#EXECUTE_AT_TARGET
INSERT INTO BWM.STG_TX_ND_HR (
    CDW_ID,
    MSMT_ID,
    ORIG_TX_ND_ID,
    ORIG_TX_ID,
    ORIG_APP_ID,
    ORIG_HOST_ID,
    ORIG_METRIC_ID,
    MEAS_HOUR,
    MIN_VALUE,
    MAX_VALUE,
    AVG_VALUE,
    TOTAL_VALUE,
    SAMPLE_COUNT,
    ERROR_COUNT)
 SELECT
  CDW_ID,
  NEXTVAL FOR BWM.STG_MSMT_ID_SEQ,
  ORIG_TX_ND_ID,
  ORIG_TX_ID,
  ORIG_APP_ID,
  ORIG_HOST_ID,
  ORIG_METRIC_ID,
  MEAS_HOUR,
  MIN_VALUE,
  MAX_VALUE,
  AVG_VALUE,
  TOTAL_VALUE,
  SAMPLE_COUNT,
  ERROR_COUNT
 FROM
  BWM.STG1_TX_ND_HR
  ;

--#EXECUTE_AT_TARGET
INSERT INTO BWM.STG_TX_ND_HR (
    CDW_ID,
    MSMT_ID,
    ORIG_TX_ND_ID,
    ORIG_TX_ID,
    ORIG_APP_ID,
    ORIG_HOST_ID,
    ORIG_METRIC_ID,
    MEAS_HOUR,
    MIN_VALUE,
    MAX_VALUE,
    AVG_VALUE,
    TOTAL_VALUE,
    SAMPLE_COUNT,
    ERROR_COUNT)
 SELECT
  CDW_ID,
  NEXTVAL FOR BWM.STG_MSMT_ID_SEQ,
  ORIG_TX_ND_ID,
  ORIG_TX_ID,
  ORIG_APP_ID,
  ORIG_HOST_ID,
  ORIG_METRIC_ID,
  MEAS_HOUR,
  MIN_VALUE,
  MAX_VALUE,
  AVG_VALUE,
  TOTAL_VALUE,
  SAMPLE_COUNT,
  ERROR_COUNT
 FROM
  BWM.STG2_TX_ND_HR
;


------------------------
-- COMP_NAME_LONG
------------------------
UPDATE TWG.EXTRACT_CONTROL
 SET EXTCTL_TO_INTSEQ=(SELECT MAX_VALUE FROM BWM.VE_COMP_NAME_LONG)
 WHERE
  EXTCTL_SOURCE='BWM.COMP_NAME_LONG' AND EXTCTL_TARGET='BWM.COMP_NAME_LONG' AND
  EXISTS (SELECT MAX_VALUE FROM BWM.VE_COMP_NAME_LONG)
    ;

--#INSERT_INTO_TARGET
INSERT INTO BWM.COMP_NAME_LONG (
    COMP_ID,
    ORIG_COMP_ID,
    COMP_NM,
    COMP_SHORT_NM,
    COMP_DS,
    COMPTYP_CD,
    COMP_STRT_DTTM,
    COMP_END_DTTM
    )
 SELECT
  0,
  A.ORIG_COMP_ID,
  A.COMP_NM,
  A.COMP_SHORT_NM,
  A.COMP_DS,
  A.COMPTYP_CD,
  A.COMP_STRT_DTTM,
  A.COMP_END_DTTM
 FROM
  BWM.VD_COMP_NAME_LONG A,
  TWG.EXTRACT_CONTROL EC
 WHERE
  EC.EXTCTL_SOURCE='BWM.COMP_NAME_LONG' AND
  EC.EXTCTL_TARGET='BWM.COMP_NAME_LONG' AND
  A.ORIG_COMP_ID>EC.EXTCTL_FROM_INTSEQ AND
  A.ORIG_COMP_ID<=EC.EXTCTL_TO_INTSEQ
;

INSERT INTO TWG.EXTRACT_LOG
 SELECT
  EC.EXTCTL_SOURCE AS EXTLOG_SOURCE,
  EC.EXTCTL_TARGET AS EXTLOG_TARGET,
  CURRENT TIMESTAMP AS EXTLOG_DONE_DTTM,
  EC.EXTCTL_FROM_RAWSEQ AS EXTLOG_FROM_RAWSEQ,
  EC.EXTCTL_TO_RAWSEQ AS EXTLOG_TO_RAWSEQ,
  EC.EXTCTL_FROM_INTSEQ AS EXTLOG_FROM_INTSEQ,
  EC.EXTCTL_TO_INTSEQ AS EXTLOG_TO_INTSEQ,
  EC.EXTCTL_FROM_DTTM AS EXTLOG_FROM_DTTM,
  EC.EXTCTL_TO_DTTM AS EXTLOG_TO_DTTM
 FROM
  TWG.EXTRACT_CONTROL EC
 WHERE
  EC.EXTCTL_SOURCE='BWM.COMP_NAME_LONG' AND
  EC.EXTCTL_TARGET='BWM.COMP_NAME_LONG'
;

------------------------
-- COMP_ATTR_LONG
------------------------
UPDATE TWG.EXTRACT_CONTROL
 SET EXTCTL_TO_INTSEQ=(SELECT MAX_VALUE FROM BWM.VE_COMP_ATTR_LONG)
 WHERE
  EXTCTL_SOURCE='BWM.COMP_ATTR_LONG' AND EXTCTL_TARGET='BWM.COMP_ATTR_LONG' AND
  EXISTS (SELECT MAX_VALUE FROM BWM.VE_COMP_ATTR_LONG)
    ;

--#INSERT_INTO_TARGET
INSERT INTO BWM.COMP_ATTR_LONG (
    COMP_ID,
    ORIG_COMPATTR_ID,
    ORIG_COMP_ID,
    ATTRTYP_CD,
    COMPATTR_VAL,
    ATTR_STRT_DTTM,
    ATTR_END_DTTM)
 SELECT
  0,
  A.ORIG_COMPATTR_ID,
  A.ORIG_COMP_ID,
  A.ATTRTYP_CD,
  A.COMPATTR_VAL,
  A.ATTR_STRT_DTTM,
  A.ATTR_END_DTTM
 FROM
  BWM.VD_COMP_ATTR_LONG A,
  TWG.EXTRACT_CONTROL EC
 WHERE
  EC.EXTCTL_SOURCE='BWM.COMP_ATTR_LONG' AND
  EC.EXTCTL_TARGET='BWM.COMP_ATTR_LONG' AND
  A.ORIG_COMPATTR_ID>EC.EXTCTL_FROM_INTSEQ AND
  A.ORIG_COMPATTR_ID<=EC.EXTCTL_TO_INTSEQ
;

INSERT INTO TWG.EXTRACT_LOG
 SELECT
  EC.EXTCTL_SOURCE AS EXTLOG_SOURCE,
  EC.EXTCTL_TARGET AS EXTLOG_TARGET,
  CURRENT TIMESTAMP AS EXTLOG_DONE_DTTM,
  EC.EXTCTL_FROM_RAWSEQ AS EXTLOG_FROM_RAWSEQ,
  EC.EXTCTL_TO_RAWSEQ AS EXTLOG_TO_RAWSEQ,
  EC.EXTCTL_FROM_INTSEQ AS EXTLOG_FROM_INTSEQ,
  EC.EXTCTL_TO_INTSEQ AS EXTLOG_TO_INTSEQ,
  EC.EXTCTL_FROM_DTTM AS EXTLOG_FROM_DTTM,
  EC.EXTCTL_TO_DTTM AS EXTLOG_TO_DTTM
 FROM
  TWG.EXTRACT_CONTROL EC
 WHERE
  EC.EXTCTL_SOURCE='BWM.COMP_ATTR_LONG' AND
  EC.EXTCTL_TARGET='BWM.COMP_ATTR_LONG'
;
