----------------------------------------------------------------------------------------------------
--   OCO Source Materials
--
--   Licensed Materials - Property of IBM
--
--   5724-C02
--
--   (C) Copyright IBM Corp. 2003  All Rights Reserved.
--
--   US Government Users Restricted Rights - Use, duplication or
--   disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
----------------------------------------------------------------------------------------------------
--    File Information: %W%
--    Revision: %I%
--    Date: %G% %U%
----------------------------------------------------------------------------------------------------

--#iftag fixpack_5

-------------------------------------------------------
-- Prune tables
-------------------------------------------------------
CREATE TABLE BWM.PRUNE_MART_CONTROL(
    TABLE_NAME       VARCHAR(120) NOT NULL,
    PMARTC_DURATION  DECIMAL(8,0) NOT NULL
    );

CREATE TABLE BWM.PRUNE_MART_LOG(
    PMART_RUN_DTTM   TIMESTAMP NOT NULL,
    TABLE_NAME       VARCHAR(30),
    PMARTC_DURATION  DECIMAL(8,0) NOT NULL,
    NUMBER_PRUNED    DECIMAL(8,0) NOT NULL
    );

----------------------------
--- Dimension Table:  Host
----------------------------
CREATE TABLE BWM.D_HOST(
    HOST_ID          INTEGER NOT NULL,
    HOST_NM          VARCHAR(254) NOT NULL,
    IP_ADDRESS       VARCHAR(254),
    CUST_NM          VARCHAR(254),
    CENTER_NM        VARCHAR(254),
    PRIMARY KEY(HOST_ID)
    );

--SEQUENCE
CREATE SEQUENCE BWM.HOST_ID_SEQ
 START WITH 0 INCREMENT BY 1 NO MAXVALUE NO CYCLE CACHE 24
;

--TRIGGER
CREATE TRIGGER BWM.HOST_IL
 NO CASCADE BEFORE INSERT ON BWM.D_HOST
 REFERENCING NEW AS N FOR EACH ROW MODE DB2SQL
 SET N.HOST_ID=NEXTVAL FOR BWM.HOST_ID_SEQ
;

-- Translation table

CREATE TABLE BWM.T_HOST(
    CDW_ID           INTEGER NOT NULL,
    HOST_ID          INTEGER,
    ORIG_HOST_ID     INTEGER NOT NULL,
    HOST_NM          VARCHAR(254) NOT NULL,
    IP_ADDRESS       VARCHAR(254),
    CUST_NM          VARCHAR(254),
    CENTER_NM        VARCHAR(254),
    PRIMARY KEY(ORIG_HOST_ID,CDW_ID)
    );

--------------------
---  TX
--------------------


-----------------------------
-- dimension table: TX
-----------------------------
CREATE TABLE BWM.D_TX(
    TX_ID            INTEGER NOT NULL,
    TX_NAME          VARCHAR(254),
    TX_DESC          VARCHAR(254),
    URL_PROTOCOL      VARCHAR(254),
    WEBSITE          VARCHAR(254),
    WEBSITE_PATH     VARCHAR(254),
    WEBSITE_QUERY    VARCHAR(254),
    PRIMARY KEY(TX_ID)
    );
--sequence
CREATE SEQUENCE BWM.TX_ID_SEQ
 START WITH 0 INCREMENT BY 1 NO MAXVALUE NO CYCLE CACHE 24
;
--trigger
CREATE TRIGGER BWM.TX_IL
 NO CASCADE BEFORE INSERT ON BWM.D_TX
 REFERENCING NEW AS N FOR EACH ROW MODE DB2SQL
 SET N.TX_ID=NEXTVAL FOR BWM.TX_ID_SEQ
;


-- translation table
CREATE TABLE BWM.T_TX(
    ORIG_TX_ID     INTEGER NOT NULL,
    CDW_ID         INTEGER NOT NULL,
    TX_ID          INTEGER NOT NULL,
    TX_NAME        VARCHAR(254),
    TX_DESC        VARCHAR(254),
    URL_PROTOCOL    VARCHAR(254),
    WEBSITE        VARCHAR(254),
    WEBSITE_PATH   VARCHAR(254),
    WEBSITE_QUERY  VARCHAR(254),
    PRIMARY KEY(ORIG_TX_ID,CDW_ID)
    );

-----------------------
-- APP
-----------------------
CREATE TABLE BWM.D_APP(
    APP_ID           INTEGER NOT NULL,
    J2EESERVER_NAME  VARCHAR(254),
    J2EE_CELL_NAME   VARCHAR(254),
    J2EE_DOMAIN      VARCHAR(254),
    J2EE_NODE        VARCHAR(254),
    J2EE_TYPE_VER    VARCHAR(254),
    PROBE_NAME       VARCHAR(254),
    PROBE_HOST       VARCHAR(254),
    PRIMARY KEY(APP_ID)
    );
--sequence
CREATE SEQUENCE BWM.APP_ID_SEQ
 START WITH 0 INCREMENT BY 1 NO MAXVALUE NO CYCLE CACHE 24
;
--trigger
CREATE TRIGGER BWM.APP_IL
 NO CASCADE BEFORE INSERT ON BWM.D_APP
 REFERENCING NEW AS N FOR EACH ROW MODE DB2SQL
 SET N.APP_ID=NEXTVAL FOR BWM.APP_ID_SEQ
;
CREATE TABLE BWM.T_APP(
    ORIG_APP_ID      INTEGER NOT NULL,
    CDW_ID           INTEGER NOT NULL,
    APP_ID           INTEGER,
    J2EESERVER_NAME  VARCHAR(254),
    J2EE_CELL_NAME   VARCHAR(254),
    J2EE_DOMAIN      VARCHAR(254),
    J2EE_NODE        VARCHAR(254),
    J2EE_TYPE_VER    VARCHAR(254),
    PROBE_NAME       VARCHAR(254),
    PROBE_HOST       VARCHAR(254),
    PRIMARY KEY(ORIG_APP_ID,CDW_ID)
    );

--------------------
---  TX_NODE
--------------------

-----------------------------
-- dimension table: TX_NODE
-----------------------------
CREATE TABLE BWM.D_TX_ND(
    TX_ND_ID            INTEGER NOT NULL,
    TX_ND_NAME          VARCHAR(254),
    MANAGEMENT_POLICY   VARCHAR(254),
    INVOKING_USER       VARCHAR(254),
    CURRENT_CDW_ID      VARCHAR(254),
    ROOT_CDW_ID         VARCHAR(254),
    PARENT_CDW_ID       VARCHAR(254),
    PRIMARY KEY(TX_ND_ID)
    );
--sequence
CREATE SEQUENCE BWM.TX_ND_ID_SEQ
 START WITH 0 INCREMENT BY 1 NO MAXVALUE NO CYCLE CACHE 24
;
--trigger
CREATE TRIGGER BWM.TX_ND_IL
 NO CASCADE BEFORE INSERT ON BWM.D_TX_ND
 REFERENCING NEW AS N FOR EACH ROW MODE DB2SQL
 SET N.TX_ND_ID=NEXTVAL FOR BWM.TX_ND_ID_SEQ
;

CREATE TABLE BWM.T_TX_ND(
    ORIG_TX_ND_ID       INTEGER NOT NULL,
    TX_ND_ID            INTEGER NOT NULL,
    CDW_ID              INTEGER NOT NULL,
    TX_ND_NAME          VARCHAR(254),
    MANAGEMENT_POLICY   VARCHAR(254),
    INVOKING_USER       VARCHAR(254),
    ROOT_CDW_ID         VARCHAR(254),
    PARENT_CDW_ID       VARCHAR(254),
    PRIMARY KEY(ORIG_TX_ND_ID,CDW_ID)
    );

---------------------------------
-- dimension table: TX_NODE metric
---------------------------------
CREATE TABLE BWM.D_TX_ND_METRIC(
    METRIC_ID           INTEGER NOT NULL,
    MET_CATEGORY        VARCHAR(254),
    MET_DESC            VARCHAR(254),
    MET_NAME            VARCHAR(254),
    MET_UNITS VARCHAR(254),
    MIN_EXISTS          CHAR(1) NOT NULL,
    MAX_EXISTS          CHAR(1) NOT NULL,
    AVG_EXISTS          CHAR(1) NOT NULL,
    TOTAL_EXISTS        CHAR(1) NOT NULL,
    MSRC_NM             VARCHAR(254),
    PRIMARY KEY (METRIC_ID)
    );

--sequence
CREATE SEQUENCE BWM.TX_ND_METRIC_ID_SEQ
 START WITH 0 INCREMENT BY 1 NO MAXVALUE NO CYCLE CACHE 24
;

--trigger
CREATE TRIGGER BWM.TX_ND_METRIC_IL
 NO CASCADE BEFORE INSERT ON BWM.D_TX_ND_METRIC
 REFERENCING NEW AS N FOR EACH ROW MODE DB2SQL
 SET N.METRIC_ID=NEXTVAL FOR BWM.TX_ND_METRIC_ID_SEQ
;
-- translation table
CREATE TABLE BWM.T_TX_ND_METRIC(
    ORIG_METRIC_ID      INTEGER NOT NULL,
    CDW_ID              INTEGER NOT NULL,
    METRIC_ID           INTEGER NOT NULL,
    MET_CATEGORY        VARCHAR(254),
    MET_DESC            VARCHAR(254),
    MET_NAME            VARCHAR(254) NOT NULL,
    MET_UNITS VARCHAR(254),
    MIN_EXISTS CHAR(1) NOT NULL,
    MAX_EXISTS          CHAR(1) NOT NULL,
    AVG_EXISTS          CHAR(1) NOT NULL,
    TOTAL_EXISTS        CHAR(1) NOT NULL,
    MSRC_NM             VARCHAR(254),
    PRIMARY KEY (ORIG_METRIC_ID,CDW_ID)
    );


----------------------------
-- hourly fact table: TX_NODE
-----------------------------
CREATE TABLE BWM.F_TX_ND_HOUR(
    METRIC_ID        INTEGER NOT NULL,
    TX_ND_ID         INTEGER NOT NULL,
    TX_ID            INTEGER NOT NULL,
    APP_ID           INTEGER NOT NULL,
    HOST_ID          INTEGER NOT NULL,
    MEAS_HOUR        TIMESTAMP NOT NULL,
    MIN_VALUE        DOUBLE,
    MAX_VALUE        DOUBLE,
    AVG_VALUE        DOUBLE,
    TOTAL_VALUE      DOUBLE,
    SAMPLE_COUNT     BIGINT,
    ERROR_COUNT      BIGINT,
    PRIMARY KEY (METRIC_ID,TX_ND_ID,TX_ID,APP_ID,HOST_ID,MEAS_HOUR)
    );
CREATE INDEX F_TXND_HR1 ON BWM.F_TX_ND_HOUR(METRIC_ID);
CREATE INDEX F_TXND_HR2 ON BWM.F_TX_ND_HOUR(TX_ND_ID);
CREATE INDEX F_TXND_HR3 ON BWM.F_TX_ND_HOUR(TX_ID);
CREATE INDEX F_TXND_HR4 ON BWM.F_TX_ND_HOUR(APP_ID);
CREATE INDEX F_TXND_HR9 ON BWM.F_TX_ND_HOUR(HOST_ID);


ALTER TABLE BWM.F_TX_ND_HOUR ADD CONSTRAINT K_TX_ND_HR_1
 FOREIGN KEY(METRIC_ID) REFERENCES BWM.D_TX_ND_METRIC(METRIC_ID);
ALTER TABLE BWM.F_TX_ND_HOUR ADD CONSTRAINT K_TX_ND_HR_2
 FOREIGN KEY(TX_ND_ID) REFERENCES BWM.D_TX_ND(TX_ND_ID);
ALTER TABLE BWM.F_TX_ND_HOUR ADD CONSTRAINT K_TX_ND_HR_3
 FOREIGN KEY(TX_ID) REFERENCES BWM.D_TX(TX_ID);
ALTER TABLE BWM.F_TX_ND_HOUR ADD CONSTRAINT K_TX_ND_HR_4
 FOREIGN KEY(APP_ID) REFERENCES BWM.D_APP(APP_ID);
ALTER TABLE BWM.F_TX_ND_HOUR ADD CONSTRAINT K_TX_ND_HR_9
 FOREIGN KEY(HOST_ID) REFERENCES BWM.D_HOST(HOST_ID);


-----------------------------
-- daily fact table: TX_NODE
-----------------------------

CREATE TABLE BWM.F_TX_ND_DAY(
    METRIC_ID     INTEGER NOT NULL,
    TX_ND_ID      INTEGER NOT NULL,
    TX_ID         INTEGER NOT NULL,
    APP_ID        INTEGER NOT NULL,
    HOST_ID       INTEGER NOT NULL,
    MEAS_DATE TIMESTAMP NOT NULL,
    MIN_VALUE     DOUBLE,
    MAX_VALUE     DOUBLE,
    AVG_VALUE     DOUBLE,
    TOTAL_VALUE   DOUBLE,
    SAMPLE_COUNT  BIGINT,
    ERROR_COUNT   BIGINT,
    PRIMARY KEY (METRIC_ID,TX_ND_ID,TX_ID,APP_ID,HOST_ID,MEAS_DATE)
    );
CREATE INDEX F_TXND_DAY1 ON BWM.F_TX_ND_DAY(METRIC_ID);
CREATE INDEX F_TXND_DAY2 ON BWM.F_TX_ND_DAY(TX_ND_ID);
CREATE INDEX F_TXND_DAY3 ON BWM.F_TX_ND_DAY(TX_ID);
CREATE INDEX F_TXND_DAY4 ON BWM.F_TX_ND_DAY(APP_ID);
CREATE INDEX F_TXND_DAY9 ON BWM.F_TX_ND_DAY(HOST_ID);

ALTER TABLE BWM.F_TX_ND_DAY ADD CONSTRAINT K_TX_ND_DAY_1
 FOREIGN KEY(METRIC_ID) REFERENCES BWM.D_TX_ND_METRIC(METRIC_ID);
ALTER TABLE BWM.F_TX_ND_DAY ADD CONSTRAINT K_TX_ND_DAY_2
 FOREIGN KEY(TX_ND_ID) REFERENCES BWM.D_TX_ND(TX_ND_ID);
ALTER TABLE BWM.F_TX_ND_DAY ADD CONSTRAINT K_TX_ND_DAY_3
 FOREIGN KEY(TX_ID) REFERENCES BWM.D_TX(TX_ID);
ALTER TABLE BWM.F_TX_ND_DAY ADD CONSTRAINT K_TX_ND_DAY_4
 FOREIGN KEY(APP_ID) REFERENCES BWM.D_APP(APP_ID);
ALTER TABLE BWM.F_TX_ND_DAY ADD CONSTRAINT K_TX_ND_DAY_9
 FOREIGN KEY(HOST_ID) REFERENCES BWM.D_HOST(HOST_ID);

-----------------------------
-- WEEKLY fact table: TX_NODE
-----------------------------

CREATE TABLE BWM.F_TX_ND_WEEK(
    METRIC_ID     INTEGER NOT NULL,
    TX_ND_ID      INTEGER NOT NULL,
    TX_ID         INTEGER NOT NULL,
    APP_ID        INTEGER NOT NULL,
    HOST_ID       INTEGER NOT NULL,
    MEAS_DATE TIMESTAMP NOT NULL,
    MIN_VALUE     DOUBLE,
    MAX_VALUE     DOUBLE,
    AVG_VALUE     DOUBLE,
    TOTAL_VALUE   DOUBLE,
    SAMPLE_COUNT  BIGINT,
    ERROR_COUNT   BIGINT,
    PRIMARY KEY (METRIC_ID,TX_ND_ID,TX_ID,APP_ID,HOST_ID,MEAS_DATE)
    );
CREATE INDEX F_TXND_WEEK1 ON BWM.F_TX_ND_WEEK(METRIC_ID);
CREATE INDEX F_TXND_WEEK2 ON BWM.F_TX_ND_WEEK(TX_ND_ID);
CREATE INDEX F_TXND_WEEK3 ON BWM.F_TX_ND_WEEK(TX_ID);
CREATE INDEX F_TXND_WEEK4 ON BWM.F_TX_ND_WEEK(APP_ID);
CREATE INDEX F_TXND_WEEK9 ON BWM.F_TX_ND_WEEK(HOST_ID);

ALTER TABLE BWM.F_TX_ND_WEEK ADD CONSTRAINT K_TX_ND_WEEK_1
 FOREIGN KEY(METRIC_ID) REFERENCES BWM.D_TX_ND_METRIC(METRIC_ID);
ALTER TABLE BWM.F_TX_ND_WEEK ADD CONSTRAINT K_TX_ND_WEEK_2
 FOREIGN KEY(TX_ND_ID) REFERENCES BWM.D_TX_ND(TX_ND_ID);
ALTER TABLE BWM.F_TX_ND_WEEK ADD CONSTRAINT K_TX_ND_WEEK_3
 FOREIGN KEY(TX_ID) REFERENCES BWM.D_TX(TX_ID);
ALTER TABLE BWM.F_TX_ND_WEEK ADD CONSTRAINT K_TX_ND_WEEK_4
 FOREIGN KEY(APP_ID) REFERENCES BWM.D_APP(APP_ID);
ALTER TABLE BWM.F_TX_ND_WEEK ADD CONSTRAINT K_TX_ND_WEEK_9
 FOREIGN KEY(HOST_ID) REFERENCES BWM.D_HOST(HOST_ID);

-----------------------------
-- MONTHLY fact table: TX_NODE
-----------------------------

CREATE TABLE BWM.F_TX_ND_MONTH(
    METRIC_ID     INTEGER NOT NULL,
    TX_ND_ID      INTEGER NOT NULL,
    TX_ID         INTEGER NOT NULL,
    APP_ID        INTEGER NOT NULL,
    HOST_ID       INTEGER NOT NULL,
    MEAS_DATE TIMESTAMP NOT NULL,
    MIN_VALUE     DOUBLE,
    MAX_VALUE     DOUBLE,
    AVG_VALUE     DOUBLE,
    TOTAL_VALUE   DOUBLE,
    SAMPLE_COUNT  BIGINT,
    ERROR_COUNT   BIGINT,
    PRIMARY KEY (METRIC_ID,TX_ND_ID,TX_ID,APP_ID,HOST_ID,MEAS_DATE)
    );
CREATE INDEX F_TXND_MONTH1 ON BWM.F_TX_ND_MONTH(METRIC_ID);
CREATE INDEX F_TXND_MONTH2 ON BWM.F_TX_ND_MONTH(TX_ND_ID);
CREATE INDEX F_TXND_MONTH3 ON BWM.F_TX_ND_MONTH(TX_ID);
CREATE INDEX F_TXND_MONTH4 ON BWM.F_TX_ND_MONTH(APP_ID);
CREATE INDEX F_TXND_MONTH9 ON BWM.F_TX_ND_MONTH(HOST_ID);

ALTER TABLE BWM.F_TX_ND_MONTH ADD CONSTRAINT K_TX_ND_MONTH_1
 FOREIGN KEY(METRIC_ID) REFERENCES BWM.D_TX_ND_METRIC(METRIC_ID);
ALTER TABLE BWM.F_TX_ND_MONTH ADD CONSTRAINT K_TX_ND_MONTH_2
 FOREIGN KEY(TX_ND_ID) REFERENCES BWM.D_TX_ND(TX_ND_ID);
ALTER TABLE BWM.F_TX_ND_MONTH ADD CONSTRAINT K_TX_ND_MONTH_3
 FOREIGN KEY(TX_ID) REFERENCES BWM.D_TX(TX_ID);
ALTER TABLE BWM.F_TX_ND_MONTH ADD CONSTRAINT K_TX_ND_MONTH_4
 FOREIGN KEY(APP_ID) REFERENCES BWM.D_APP(APP_ID);
ALTER TABLE BWM.F_TX_ND_MONTH ADD CONSTRAINT K_TX_ND_MONTH_9
 FOREIGN KEY(HOST_ID) REFERENCES BWM.D_HOST(HOST_ID);


-----------------------------
-- FACT DATA STAGE TABLES
-----------------------------

CREATE TABLE BWM.STG_TX_ND_HR(
    CDW_ID INTEGER NOT NULL,
    MSMT_ID BIGINT NOT NULL,
    ORIG_TX_ND_ID INTEGER NOT NULL,
    ORIG_TX_ID INTEGER NOT NULL,
    ORIG_APP_ID INTEGER NOT NULL,
    ORIG_HOST_ID INTEGER NOT NULL,
    ORIG_METRIC_ID INTEGER NOT NULL,
    MEAS_HOUR TIMESTAMP NOT NULL,
    MIN_VALUE DOUBLE,
    MAX_VALUE DOUBLE,
    AVG_VALUE DOUBLE,
    TOTAL_VALUE DOUBLE,
    SAMPLE_COUNT BIGINT,
    ERROR_COUNT BIGINT,
    PRIMARY KEY (ORIG_TX_ND_ID,ORIG_TX_ID,ORIG_APP_ID,
     ORIG_HOST_ID,ORIG_METRIC_ID,CDW_ID,MEAS_HOUR)
    );

CREATE TABLE BWM.STG1_TX_ND_HR(
    CDW_ID INTEGER NOT NULL,
    ORIG_TX_ND_ID INTEGER NOT NULL,
    ORIG_TX_ID INTEGER NOT NULL,
    ORIG_APP_ID INTEGER NOT NULL,
    ORIG_HOST_ID INTEGER NOT NULL,
    ORIG_METRIC_ID INTEGER NOT NULL,
    MEAS_HOUR TIMESTAMP NOT NULL,
    MIN_VALUE DOUBLE,
    MAX_VALUE DOUBLE,
    AVG_VALUE DOUBLE,
    TOTAL_VALUE DOUBLE,
    SAMPLE_COUNT BIGINT,
    ERROR_COUNT BIGINT,
    PRIMARY KEY (ORIG_TX_ND_ID,ORIG_TX_ID,ORIG_APP_ID,
     ORIG_HOST_ID,ORIG_METRIC_ID,CDW_ID,MEAS_HOUR)
    );

CREATE TABLE BWM.STG2_TX_ND_HR(
    CDW_ID INTEGER NOT NULL,
    ORIG_TX_ND_ID INTEGER NOT NULL,
    ORIG_TX_ID INTEGER NOT NULL,
    ORIG_APP_ID INTEGER NOT NULL,
    ORIG_HOST_ID INTEGER NOT NULL,
    ORIG_METRIC_ID INTEGER NOT NULL,
    MEAS_HOUR TIMESTAMP NOT NULL,
    MIN_VALUE DOUBLE,
    MAX_VALUE DOUBLE,
    AVG_VALUE DOUBLE,
    TOTAL_VALUE DOUBLE,
    SAMPLE_COUNT BIGINT,
    ERROR_COUNT BIGINT,
    PRIMARY KEY (ORIG_TX_ND_ID,ORIG_TX_ID,ORIG_APP_ID,
     ORIG_HOST_ID,ORIG_METRIC_ID,CDW_ID,MEAS_HOUR)
    );

--SEQUENCE
CREATE SEQUENCE BWM.STG_MSMT_ID_SEQ
 START WITH 0 INCREMENT BY 1 NO MAXVALUE NO CYCLE CACHE 24
;

--#endtag fixpack_5
