-------------------------------------------------------------------------------
--   OCO Source Materials
--
--   Licensed Materials - Property of IBM
--
--   5724-C02
--
--   (C) Copyright IBM Corp. 2003  All Rights Reserved.
--
--   US Government Users Restricted Rights - Use, duplication or
--   disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
-------------------------------------------------------------------------------
--    File Information: %W%
--    Revision: %I%
--    Date: %G% %U%
-------------------------------------------------------------------------------

--#iftag fixpack_5


-------------------------------------------------------------------------------
-- Static data for IBM Tivoli for Transaction Performance
-------------------------------------------------------------------------------
-- create a temporary table for generic component types
-------------------------------------------------------------------------------
declare global temporary table CompTyp (
       CompTyp_Cd           CHAR(17) NOT NULL,
       CompTyp_Parent_Cd    CHAR(17),
       CompTyp_Nm           VARCHAR(120) NOT NULL,
       CompTyp_Strt_DtTm    TIMESTAMP NOT NULL,
       CompTyp_End_DtTm     TIMESTAMP NOT NULL
)
with replace on commit preserve rows not logged
;

-------------------------------------------------------------------------------
-- insert the component types into temporary table for generic component types
-------------------------------------------------------------------------------
INSERT INTO session.CompTyp VALUES ('IP_HOST', NULL, 'IP Host', CURRENT timestamp - CURRENT timezone, '9999-01-01-00.00.00.000000');
INSERT INTO session.CompTyp VALUES ('BWM_TX_NODE', NULL, 'Transaction Node', CURRENT timestamp - CURRENT timezone, '9999-01-01-00.00.00.000000');
INSERT INTO session.CompTyp VALUES ('BWM_TRANSACTION', NULL, 'Transaction', CURRENT timestamp - CURRENT timezone, '9999-01-01-00.00.00.000000');
INSERT INTO session.CompTyp VALUES ('BWM_PROBE', NULL, 'Monitoring Probe', CURRENT timestamp - CURRENT timezone, '9999-01-01-00.00.00.000000');
INSERT INTO session.CompTyp VALUES ('BWM_HOST', NULL, 'Transaction Host', CURRENT timestamp - CURRENT timezone, '9999-01-01-00.00.00.000000');
INSERT INTO session.CompTyp VALUES ('J2EE_CELL', NULL, 'J2EE Cell', CURRENT timestamp - CURRENT timezone, '9999-01-01-00.00.00.000000');

-------------------------------------------------------------------------------
-- insert the component types into the generic schema
-- if not exist already
-------------------------------------------------------------------------------
insert into TWG.CompTyp
select
 c.CompTyp_Cd,
 c.CompTyp_Parent_Cd,
 c.CompTyp_Nm,
 c.CompTyp_Strt_DtTm,
 c.CompTyp_End_DtTm
from
 session.CompTyp c
where not exists
( select 1 from
  TWG.Cur_CompTyp t
  where
  t.CompTyp_cd=c.CompTyp_cd)
  ;


-------------------------------------------------------------------------------
-- create a temporary table for measurement source cd
-------------------------------------------------------------------------------
declare global temporary table MSrc (
       MSrc_Cd              CHAR(6) NOT NULL,
       MSrc_Parent_Cd       CHAR(6) NOT NULL,
       MSrc_Nm              VARCHAR(120) NOT NULL
)
with replace on commit preserve rows not logged
;



insert into session.MSrc values ('BWM', 'Tivoli', 'IBM Tivoli Monitoring For Transaction Performance 5.2');

insert into TWG.MSrc
select
 m.MSrc_Cd,
 m.MSrc_Parent_Cd,
 m.MSrc_Nm
from
 session.MSrc m
where not exists
( select 1 from
  TWG.MSrc t
  where
  t.MSrc_Cd=m.MSrc_Cd )
  ;




-------------------------------------------------------------------------------
-- create a temporary table for TMTP measurement types
-------------------------------------------------------------------------------
declare global temporary table BWM_MsmtTyp (
       MUnit_Cd          CHAR(6) NOT NULL,
       MSrc_Cd		    CHAR(6) NOT NULL,
       MsmtTyp_Nm           VARCHAR(120) NOT NULL,
       MsmtTyp_Ds           VARCHAR(254)
)
with replace on commit preserve rows not logged
;


INSERT into session.BWM_MsmtTyp(MSrc_Cd, Munit_Cd,MsmtTyp_Nm, MsmtTyp_Ds) VALUES ( 'MODEL1', 'MSec', 'Response Time', 'The transaction response time');
INSERT into session.BWM_MsmtTyp(MSrc_Cd, Munit_Cd,MsmtTyp_Nm, MsmtTyp_Ds) VALUES ( 'BWM', 'Sec', 'Round Trip Time', 'The round trip response time');
INSERT into session.BWM_MsmtTyp(MSrc_Cd, Munit_Cd,MsmtTyp_Nm, MsmtTyp_Ds) VALUES ( 'BWM', 'Sec', 'Service Time', 'The backend service response time');
INSERT into session.BWM_MsmtTyp(MSrc_Cd, Munit_Cd,MsmtTyp_Nm, MsmtTyp_Ds) VALUES ( 'BWM', 'Sec', 'Page Render Time', 'The page render response time');
INSERT into session.BWM_MsmtTyp(MSrc_Cd, Munit_Cd,MsmtTyp_Nm, MsmtTyp_Ds) VALUES ( 'BWM', 'QTY', 'Number Threshold Exceeded', 'The number of transaction thresholds that exceeded');
INSERT into session.BWM_MsmtTyp(MSrc_Cd, Munit_Cd,MsmtTyp_Nm, MsmtTyp_Ds) VALUES ( 'BWM', 'PRC', 'Successful Transactions', 'The percentage of synthetic transactions that were successful');
INSERT into session.BWM_MsmtTyp(MSrc_Cd, Munit_Cd,MsmtTyp_Nm, MsmtTyp_Ds) VALUES ( 'BWM', 'PRC', 'Unsuccessful Transactions', 'The percentage of synthetic transactions that failed');
INSERT into session.BWM_MsmtTyp(MSrc_Cd, Munit_Cd,MsmtTyp_Nm, MsmtTyp_Ds) VALUES ( 'BWM', 'QTY', 'Number of Executions', 'Number of Times a transaction was executed');


-------------------------------------------------------------------------------
-- insert the measurement types into the generic schema
-- if not exist already
-------------------------------------------------------------------------------
INSERT into TWG.MsmtTyp (MUnit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds)
select
 m.MUnit_Cd,
 m.MSrc_Cd,
 m.MsmtTyp_Nm,
 m.MsmtTyp_Ds
from
 session.BWM_MsmtTyp m
where not exists
( select 1 from
  TWG.MsmtTyp t
  where
  t.MsmtTyp_Nm=m.MsmtTyp_Nm)
  ;



-------------------------------------------------------------------------------
-- create a temporary table for Transaction performance measurement rules
-------------------------------------------------------------------------------
 declare global temporary table BWM_MsmtRul (
       CompTyp_Cd           CHAR(17) NOT NULL,
       MsmtTyp_ID           INTEGER NOT NULL
)
with replace on commit preserve rows not logged
;
insert into session.BWM_MsmtRul
select 'BWM_TX_NODE', mt.MsmtTyp_ID from TWG.MsmtTyp mt where MsmtTyp_Nm in (
'Response Time',
'Round Trip Time',
'Service Time',
'Page Render Time',
'Number Threshold Exceeded',
'Successful Transactions',
'Unsuccessful Transactions',
'Number of Executions'
);


-------------------------------------------------------------------------------
-- insert the measurement rule into the generic schema
-- if not exist already
-------------------------------------------------------------------------------
insert into TWG.MsmtRul
select
 m.CompTyp_Cd,
 m.MsmtTyp_ID
from
 session.BWM_MsmtRul m
where not exists
( select 1 from
  TWG.MsmtRul t
  where
  t.MsmtTyp_ID=m.MsmtTyp_ID AND
  t.CompTyp_Cd=m.CompTyp_Cd)
  ;





-------------------------------------------------------------------------------
-- create a temporary table for component attribute types
-------------------------------------------------------------------------------
declare global temporary table BWM_AttrTyp (
       AttrTyp_Cd           CHAR(17) NOT NULL,
       AttrTyp_Nm           VARCHAR(120) NOT NULL
)
with replace on commit preserve rows not logged
;

insert into session.BWM_AttrTyp values ('URL_PROTOCOL', 'Transaction Protocol');
insert into session.BWM_AttrTyp values ('WEBSITE', 'Website');
insert into session.BWM_AttrTyp values ('WEBSITE_PATH', 'Website Path');
insert into session.BWM_AttrTyp values ('WEBSITE_QUERY', 'Website Query');
insert into session.BWM_AttrTyp values ('BWM_THRESHOLD_1', 'Transaction Threshold of Severity 10');
insert into session.BWM_AttrTyp values ('BWM_THRESHOLD_2', 'Transaction Threshold of Severity 20');
insert into session.BWM_AttrTyp values ('BWM_THRESHOLD_3', 'Transaction Threshold of Severity 30');
insert into session.BWM_AttrTyp values ('BWM_THRESHOLD_4', 'Transaction Threshold of Severity 40');
insert into session.BWM_AttrTyp values ('BWM_THRESHOLD_5', 'Transaction Threshold of Severity 50');
insert into session.BWM_AttrTyp values ('BWM_THRESHOLD_6', 'Transaction Threshold of Severity 60');
insert into session.BWM_AttrTyp values ('J2EE_CELL', 'J2EE Cell');
insert into session.BWM_AttrTyp values ('BWM_MGMT_POLICY', 'Transaction Management Policy');
insert into session.BWM_AttrTyp values ('BWM_RT_CDW_ID', 'Warehouse Component Identifier for the Root Transaction');
insert into session.BWM_AttrTyp values ('BWM_PT_CDW_ID', 'Warehouse Component Identifier for the Parent Transaction');
-------------------------------------------------------------------------------
-- insert the attribute types into the generic schema
-- if not exist already
-------------------------------------------------------------------------------
insert into TWG.AttrTyp
select
 m.AttrTyp_Cd,
 m.AttrTyp_Nm
from
 session.BWM_AttrTyp m
where not exists
( select 1 from
  TWG.AttrTyp t
  where
  t.AttrTyp_Cd=m.AttrTyp_Cd )
;


-------------------------------------------------------------------------------
-- create a temporary table for measurement group member
-- Insert measurement types into the valid groups
-------------------------------------------------------------------------------
declare global temporary table BWM_MGrpMbr (
       MGrp_Cd              CHAR(6) NOT NULL,
       MGrpTyp_Cd           CHAR(6) NOT NULL,
       MsmtTyp_ID           INTEGER NOT NULL

)
with replace on commit preserve rows not logged
;


insert into session.BWM_MGrpMbr
select 'MAX_E','GROUP', mt.MsmtTyp_ID from TWG.MsmtTyp mt where MsmtTyp_Nm in (
'Response Time',
'Round Trip Time',
'Service Time',
'Page Render Time',
'Successful Transactions',
'Unsuccessful Transactions'
);

insert into session.BWM_MGrpMbr
select 'MIN_E','GROUP', mt.MsmtTyp_ID from TWG.MsmtTyp mt where MsmtTyp_Nm in (
'Response Time',
'Round Trip Time',
'Service Time',
'Page Render Time',
'Successful Transactions',
'Unsuccessful Transactions'
);

insert into session.BWM_MGrpMbr
select 'AVG_E','GROUP', mt.MsmtTyp_ID from TWG.MsmtTyp mt where MsmtTyp_Nm in (
'Response Time',
'Round Trip Time',
'Service Time',
'Page Render Time',
'Successful Transactions',
'Unsuccessful Transactions'
);


insert into session.BWM_MGrpMbr
select 'TOT_E','GROUP', mt.MsmtTyp_ID from TWG.MsmtTyp mt where MsmtTyp_Nm in (
'Number Threshold Exceeded',
'Number of Executions'
);
-------------------------------------------------------------------------------
-- insert the measurement group member into the generic schema
-- if not exist already
-------------------------------------------------------------------------------
insert into TWG.MGrpMbr
select
 m.MGrp_Cd,
 m.MGrpTyp_Cd,
 m.MsmtTyp_ID
from
 session.BWM_MGrpMbr m
where not exists
( select 1 from
  TWG.MGrpMbr t
  where
  t.MGrpTyp_Cd=m.MGrpTyp_Cd and
  t.MGrp_Cd=m.MGrp_Cd and
  t.MsmtTyp_ID=m.MsmtTyp_ID)
  ;

-------------------------------------------------------------------------------
-- Temporary for TWG.RelnRul
-- Here we are inserting the different types of relationships among components
-- For IBM Tivoli Monitoring for Transaction Performance
-------------------------------------------------------------------------------
declare global temporary TABLE BWM_RelnRul (
       CompTyp_Source_Cd    CHAR(17) NOT NULL,
       CompTyp_Target_Cd    CHAR(17) NOT NULL,
       RelnTyp_Cd           CHAR(6) NOT NULL,
       RelnRul_Strt_DtTm    TIMESTAMP NOT NULL,
       RelnRul_End_DtTm     TIMESTAMP NOT NULL
)
with replace on commit preserve rows not logged
;


insert into session.BWM_RelnRul values ('BWM_PROBE','IP_HOST','RUNSON',current timestamp - current timezone, '9999-01-01-00.00.00.000000');
insert into session.BWM_RelnRul values ('BWM_PROBE','IP_INTERFACE','RUNSON',current timestamp - current timezone, '9999-01-01-00.00.00.000000');
insert into session.BWM_RelnRul values ('BWM_PROBE','BWM_HOST','RUNSON',current timestamp - current timezone, '9999-01-01-00.00.00.000000');
insert into session.BWM_RelnRul values ('BWM_PROBE','BWM_TRANSACTION','PCHILD',current timestamp - current timezone, '9999-01-01-00.00.00.000000');
insert into session.BWM_RelnRul values ('BWM_PROBE','BWM_TX_NODE','INVOKE',current timestamp - current timezone, '9999-01-01-00.00.00.000000');
insert into session.BWM_RelnRul values ('BWM_TX_NODE','IP_HOST','RUNSON',current timestamp - current timezone, '9999-01-01-00.00.00.000000');
insert into session.BWM_RelnRul values ('BWM_TX_NODE','BWM_HOST','RUNSON',current timestamp - current timezone, '9999-01-01-00.00.00.000000');
insert into session.BWM_RelnRul values ('BWM_TX_NODE','IP_INTERFACE','RUNSON',current timestamp - current timezone, '9999-01-01-00.00.00.000000');
insert into session.BWM_RelnRul values ('BWM_TX_NODE','J2EE_SERVER','USES',current timestamp - current timezone, '9999-01-01-00.00.00.000000');
insert into session.BWM_RelnRul values ('BWM_TX_NODE','BWM_TRANSACTION','INSTOF',current timestamp - current timezone, '9999-01-01-00.00.00.000000');
insert into session.BWM_RelnRul values ('J2EE_CELL','J2EE_NODE','PCHILD',current timestamp - current timezone, '9999-01-01-00.00.00.000000');
insert into session.BWM_RelnRul values ('J2EE_NODE','J2EE_SERVER','PCHILD',current timestamp - current timezone, '9999-01-01-00.00.00.000000');
insert into session.BWM_RelnRul values ('J2EE_DOMAIN','J2EE_SERVER','PCHILD',current timestamp - current timezone, '9999-01-01-00.00.00.000000');
insert into session.BWM_RelnRul values ('J2EE_DOMAIN','J2EE_NODE','PCHILD',current timestamp - current timezone, '9999-01-01-00.00.00.000000');

insert into TWG.RelnRul
select
 m.CompTyp_Source_Cd as CompTyp_Source_Cd,
 m.CompTyp_Target_Cd as CompTyp_Target_Cd,
 m.RelnTyp_Cd as RelnTyp_Cd,
 m.RelnRul_Strt_DtTm as RelnRul_Strt_DtTm,
 m.RelnRul_End_DtTm as RelnRul_End_DtTm
from
 session.BWM_RelnRul m
where
 not exists
( select 1 from
  TWG.RelnRul t
  where
  t.CompTyp_Source_Cd = m.CompTyp_Source_Cd and
  t.CompTyp_Target_Cd = m.CompTyp_Target_Cd and
  t.RelnTyp_Cd = m.RelnTyp_Cd
  )
;


-------------------------------------------------------------------------------
-- temporary table for AttrRul
-------------------------------------------------------------------------------
declare global temporary table BWM_AttrRul (
       CompTyp_Cd           CHAR(17) NOT NULL,
       AttrTyp_Cd           CHAR(17) NOT NULL,
       AttrRul_Strt_DtTm    TIMESTAMP NOT NULL,
       AttrRul_End_DtTm     TIMESTAMP NOT NULL,
       AttrRul_Dom_Ind      CHAR NOT NULL
)
with replace on commit preserve rows not logged
;


insert into session.BWM_AttrRul values ('BWM_HOST','LAST_IP_ADDRESS',current timestamp - current timezone, '9999-01-01-00.00.00.000000','N');
insert into session.BWM_AttrRul values ('BWM_TX_NODE','WEBSITE',current timestamp - current timezone, '9999-01-01-00.00.00.000000','N');
insert into session.BWM_AttrRul values ('BWM_TX_NODE','WEBSITE_PATH',current timestamp - current timezone, '9999-01-01-00.00.00.000000','N');
insert into session.BWM_AttrRul values ('BWM_TX_NODE','WEBSITE_QUERY',current timestamp - current timezone, '9999-01-01-00.00.00.000000','N');
insert into session.BWM_AttrRul values ('BWM_TX_NODE','URL_PROTOCOL',current timestamp - current timezone, '9999-01-01-00.00.00.000000','N');
insert into session.BWM_AttrRul values ('BWM_TX_NODE','BWM_THRESHOLD_1',current timestamp - current timezone, '9999-01-01-00.00.00.000000','N');
insert into session.BWM_AttrRul values ('BWM_TX_NODE','BWM_THRESHOLD_2',current timestamp - current timezone, '9999-01-01-00.00.00.000000','N');
insert into session.BWM_AttrRul values ('BWM_TX_NODE','BWM_THRESHOLD_3',current timestamp - current timezone, '9999-01-01-00.00.00.000000','N');
insert into session.BWM_AttrRul values ('BWM_TX_NODE','BWM_THRESHOLD_4',current timestamp - current timezone, '9999-01-01-00.00.00.000000','N');
insert into session.BWM_AttrRul values ('BWM_TX_NODE','BWM_THRESHOLD_5',current timestamp - current timezone, '9999-01-01-00.00.00.000000','N');
insert into session.BWM_AttrRul values ('BWM_TX_NODE','BWM_THRESHOLD_6',current timestamp - current timezone, '9999-01-01-00.00.00.000000','N');
insert into session.BWM_AttrRul values ('BWM_TX_NODE','J2EE_NODE',current timestamp - current timezone, '9999-01-01-00.00.00.000000','N');
insert into session.BWM_AttrRul values ('BWM_TX_NODE','J2EE_SERVER',current timestamp - current timezone, '9999-01-01-00.00.00.000000','N');
insert into session.BWM_AttrRul values ('BWM_TX_NODE','INVOKING_USER',current timestamp - current timezone, '9999-01-01-00.00.00.000000','N');
insert into session.BWM_AttrRul values ('BWM_TX_NODE','BWM_MGMT_POLICY',current timestamp - current timezone, '9999-01-01-00.00.00.000000','N');
insert into session.BWM_AttrRul values ('BWM_TX_NODE','BWM_RT_CDW_ID',current timestamp - current timezone, '9999-01-01-00.00.00.000000','N');
insert into session.BWM_AttrRul values ('BWM_TX_NODE','BWM_PT_CDW_ID',current timestamp - current timezone, '9999-01-01-00.00.00.000000','N');
insert into session.BWM_AttrRul values ('BWM_TX_NODE','LAST_IP_ADDRESS',current timestamp - current timezone, '9999-01-01-00.00.00.000000','N');
insert into session.BWM_AttrRul values ('BWM_TX_NODE','J2EE_DOMAIN',current timestamp - current timezone, '9999-01-01-00.00.00.000000','N');
insert into session.BWM_AttrRul values ('BWM_TX_NODE','J2EE_CELL',current timestamp - current timezone, '9999-01-01-00.00.00.000000','N');
insert into session.BWM_AttrRul values ('J2EE_SERVER','MANUFACTURER',current timestamp - current timezone, '9999-01-01-00.00.00.000000','N');
insert into session.BWM_AttrRul values ('J2EE_SERVER','VERSION',current timestamp - current timezone, '9999-01-01-00.00.00.000000','N');

insert into TWG.AttrRul
select
 t.CompTyp_Cd  as CompTyp_Cd,
 t.AttrTyp_Cd as AttrTyp_Cd,
 t.AttrRul_Strt_DtTm as AttrRul_Strt_DtTm,
 t.AttrRul_End_DtTm as AttrRul_End_DtTm,
 t.AttrRul_Dom_Ind as AttrRul_Dom_Ind
from
 session.BWM_AttrRul t
where not exists
( select 1 from
  TWG.AttrRul m
  where
  t.CompTyp_Cd = m.CompTyp_Cd and
  t.AttrTyp_Cd = m.AttrTyp_Cd
  )
;




-------------------------------------------------------------------------------
--Insert data into control table for pruning data from Msmt table.
--A date duration is decimal(8,0) and has the format yyyymmdd.
-------------------------------------------------------------------------------
declare global temporary table prune_msmt_control(
       MSrc_Cd              CHAR(6) NOT NULL,
       TmSum_Cd             CHAR NOT NULL,
       PMsmtC_Age_In_Days   DECIMAL(8,0) NOT NULL
)
with replace on commit preserve rows not logged
;

insert into session.Prune_Msmt_Control values ('BWM', 'H', 00000300);
insert into session.Prune_Msmt_Control values ('BWM', 'D', 00000300);
insert into session.Prune_Msmt_Control values ('BWM', 'W', 00010000);
insert into session.Prune_Msmt_Control values ('BWM', 'M', 00010000);

insert into TWG.Prune_Msmt_Control
select * from
 session.Prune_Msmt_Control s
where not exists
( select 1 from
  TWG.Prune_Msmt_Control t
  where
  t.MSrc_Cd = s.MSrc_Cd and
  t.TmSum_Cd = s.TmSum_Cd)
;



-------------------------------------------------------------------------------
-- temporary table for Extract Control
-------------------------------------------------------------------------------
 declare global temporary table Extract_Control (
   ExtCtl_Source           varchar(120) not null,
 	ExtCtl_Target   	      varchar(120) not null,
 	ExtCtl_From_RawSeq      char(10) for bit data,
 	ExtCtl_To_RawSeq        char(10) for bit data,
 	ExtCtl_From_IntSeq      bigint,
 	ExtCtl_To_IntSeq        bigint,
 	ExtCtl_From_DtTm     	timestamp not null,
 	ExtCtl_To_DtTm       	timestamp not null
	)
with replace on commit preserve rows not logged
;


-------------------------------------------------------------------------------
-- From HOST to BWM.STAGE_HOST
-------------------------------------------------------------------------------

insert into session.extract_control values (
    'HOST',
    'BWM.STAGE_HOST',
    x'',
    x'',
    -1,
    -1,
    '1970-01-01-00.00.00.000000',
    '9999-01-01-00.00.00.000000'
);


-------------------------------------------------------------------------------
-- From TRANSACTION to BWM.STAGE_TX
-------------------------------------------------------------------------------

insert into session.extract_control values (
    'TRANSACTION',
    'BWM.STAGE_TRANSACTION',
    x'',
    x'',
    -1,
    -1,
    '1970-01-01-00.00.00.000000',
    '9999-01-01-00.00.00.000000'
);


-------------------------------------------------------------------------------
-- From USER to BWM.STAGE_USER
-------------------------------------------------------------------------------
insert into session.extract_control values (
    'ARM_USER',
    'BWM.STAGE_USER',
    x'',
    x'',
    -1,
    -1,
    '1970-01-01-00.00.00.000000',
    '9999-01-01-00.00.00.000000'
);

-------------------------------------------------------------------------------
-- From APPLICATION to BWM.STAGE_APPLICATION
-------------------------------------------------------------------------------
insert into session.extract_control values (
    'APPLICATION',
    'BWM.STAGE_APPLICATION',
    x'',
    x'',
    -1,
    -1,
    '1970-01-01-00.00.00.000000',
    '9999-01-01-00.00.00.000000'
);

-------------------------------------------------------------------------------
-- From NODE to BWM.STAGE_NODE
-------------------------------------------------------------------------------
insert into session.extract_control values (
    'NODE',
    'BWM.STAGE_NODE',
    x'',
    x'',
    -1,
    -1,
    '1970-01-01-00.00.00.000000',
    '9999-01-01-00.00.00.000000'
);

-------------------------------------------------------------------------------
-- From AGGREGATEDATA to BWM.STAGE_AGGREG_DATA
-------------------------------------------------------------------------------
insert into session.extract_control values (
    'AGGREGATEDATA',
    'BWM.STAGE_AGGREG_DATA',
    x'',
    x'',
    -1,
    -1,
    '1970-01-01-00.00.00.000000',
    '9999-01-01-00.00.00.000000'
);

-------------------------------------------------------------------------------
-- From RELATIONMAP to BWM.STAGE_RELATIONMAP
-------------------------------------------------------------------------------
insert into session.extract_control values (
    'RELATIONMAP',
    'BWM.STAGE_RELATIONMAP',
    x'',
    x'',
    -1,
    -1,
    '1970-01-01-00.00.00.000000',
    '9999-01-01-00.00.00.000000'
);

-------------------------------------------------------------------------------
-- From MANAGEMENTPOLICY to BWM.STAGE_MGMTPOLICY
-------------------------------------------------------------------------------
insert into session.extract_control values (
    'MANAGEMENTPOLICY',
    'BWM.STAGE_MGMTPOLICY',
    x'',
    x'',
    -1,
    -1,
    '1970-01-01-00.00.00.000000',
    '9999-01-01-00.00.00.000000'
);

-------------------------------------------------------------------------------
-- From PT to BWM.STAGE_PATTERN
-------------------------------------------------------------------------------
insert into session.extract_control values (
    'PT',
    'BWM.STAGE_PATTERN',
    x'',
    x'',
    -1,
    -1,
    '1970-01-01-00.00.00.000000',
    '9999-01-01-00.00.00.000000'
);

-------------------------------------------------------------------------------
-- From THRESHOLD to BWM.STAGE_THRESHOLD
-------------------------------------------------------------------------------
insert into session.extract_control values (
    'THRESHOLD',
    'BWM.STAGE_THRESHOLD',
    x'',
    x'',
    -1,
    -1,
    '1970-01-01-00.00.00.000000',
    '9999-01-01-00.00.00.000000'
);

-------------------------------------------------------------------------------
-- From TR to BWM.STAGE_TR
-------------------------------------------------------------------------------
insert into session.extract_control values (
    'TR',
    'BWM.STAGE_TR',
    x'',
    x'',
    -1,
    -1,
    '1970-01-01-00.00.00.000000',
    '9999-01-01-00.00.00.000000'
);



-----------------------------------------------
-- From Staging to the T tables
-----------------------------------------------

--
-- T_APP
--
insert into session.extract_control values (
    'TWG.COMP' ,
    'BWM.T_APP' ,
    x'',
    x'',
    -1,
    -1,
    '1970-01-01-00.00.00.000000',
    '9999-01-01-00.00.00.000000'
);

--
-- T_HOST
--
insert into session.extract_control values (
    'TWG.COMP' ,
    'BWM.T_HOST' ,
    x'',
    x'',
    -1,
    -1,
    '1970-01-01-00.00.00.000000',
    '9999-01-01-00.00.00.000000'
);

--
-- T_TX
--
insert into session.extract_control values (
    'TWG.COMP' ,
    'BWM.T_TX' ,
    x'',
    x'',
    -1,
    -1,
    '1970-01-01-00.00.00.000000',
    '9999-01-01-00.00.00.000000'
);

--
-- T_TX_ND
--
insert into session.extract_control values (
    'TWG.COMP' ,
    'BWM.T_TX_ND' ,
    x'',
    x'',
    -1,
    -1,
    '1970-01-01-00.00.00.000000',
    '9999-01-01-00.00.00.000000'
);


--
-- T_TX_ND_METRIC
--
insert into session.extract_control values (
    'BWM.STG_TX_ND_MET' ,
    'BWM.T_TX_ND_METRIC' ,
    x'',
    x'',
    -1,
    -1,
    '1970-01-01-00.00.00.000000',
    '9999-01-01-00.00.00.000000'
);

--
-- STG1_TX_ND_HR
--
insert into session.extract_control values (
    'TWG.MSMT' ,
    'BWM.STG1_TX_ND_HR' ,
    x'',
    x'',
    -1,
    -1,
    '1970-01-01-00.00.00.000000',
    '9999-01-01-00.00.00.000000'
);

--
-- STG2_TX_ND_HR
--
insert into session.extract_control values (
    'TWG.MSMT' ,
    'BWM.STG2_TX_ND_HR' ,
    x'',
    x'',
    -1,
    -1,
    '1970-01-01-00.00.00.000000',
    '9999-01-01-00.00.00.000000'
);

--
-- COMP_NAME_LONG
--
insert into session.extract_control values (
    'BWM.COMP_NAME_LONG' ,
    'BWM.COMP_NAME_LONG' ,
    x'',
    x'',
    -1,
    -1,
    '1970-01-01-00.00.00.000000',
    '9999-01-01-00.00.00.000000'
);

--
-- COMP_ATTR_LONG
--
insert into session.extract_control values (
    'BWM.COMP_ATTR_LONG' ,
    'BWM.COMP_ATTR_LONG' ,
    x'',
    x'',
    -1,
    -1,
    '1970-01-01-00.00.00.000000',
    '9999-01-01-00.00.00.000000'
);

-- insert the static data for the extract table
-- if not exist already

insert into TWG.Extract_control
select
 m.ExtCtl_Source as ExtCtl_Source,
 m.ExtCtl_Target as ExtCtl_Target,
 m.ExtCtl_From_RawSeq as ExtCtl_From_RawSeq,
 m.ExtCtl_To_RawSeq as ExtCtl_To_RawSeq,
 m.ExtCtl_From_IntSeq as ExtCtl_From_IntSeq,
 m.ExtCtl_To_IntSeq as ExtCtl_To_IntSeq,
 m.ExtCtl_From_DtTm as ExtCtl_From_DtTm,
 m.ExtCtl_To_DtTm as ExtCtl_To_DtTm
from
 session.Extract_Control m
where not exists
( select 1 from
  TWG.Extract_Control t
  where
  t.ExtCtl_Source=m.ExtCtl_Source  and
  t.ExtCtl_Target=m.ExtCtl_Target
  )
;
-------------------------------------------------------------------------------
-- temporary tables indicating which measurement is in the group MIN_E,
-- MAX_E, AVG_E, TOT_E for the BWM DataMart
-------------------------------------------------------------------------------
declare global temporary table temp_min_exists (
 msmttyp_id	integer,
 min_exists     char(1)
)
with replace on commit preserve rows not logged
;

insert into session.temp_min_exists
select
 mb.msmttyp_id,
 'Y' as min_exists
from
 twg.mgrpmbr mb
where
 mb.mgrptyp_cd = 'GROUP' and
 mb.mgrp_cd='MIN_E'
;


-------------------------------------------------------------------------------
-- select * from session.temp_min_exists;
-------------------------------------------------------------------------------
declare global temporary table temp_max_exists (
 msmttyp_id	integer,
 max_exists     char(1)
)
with replace on commit preserve rows not logged
;

insert into session.temp_max_exists
select
 mb.msmttyp_id,
 'Y' as max_exists
from
 twg.mgrpmbr mb
where
 mb.mgrptyp_cd = 'GROUP' and
 mb.mgrp_cd='MAX_E'
;

declare global temporary table temp_avg_exists (
 msmttyp_id	integer,
 avg_exists     char(1)
)
with replace on commit preserve rows not logged
;

insert into session.temp_avg_exists
select
 mb.msmttyp_id,
 'Y' as avg_exists
from
 twg.mgrpmbr mb
where
 mb.mgrptyp_cd = 'GROUP' and
 mb.mgrp_cd='AVG_E'
;

-------------------------------------------------------------------------------
-- select * from session.temp_avg_exists;
-------------------------------------------------------------------------------
declare global temporary table temp_tot_exists (
 msmttyp_id	integer,
 tot_exists     char(1)
)
with replace on commit preserve rows not logged
;

insert into session.temp_tot_exists
select
 mb.msmttyp_id,
 'Y' as tot_exists
from
 twg.mgrpmbr mb
where
 mb.mgrptyp_cd = 'GROUP' and
 mb.mgrp_cd='TOT_E'
;

-------------------------------------------------------------------------------
-- insert the  measurement types in the metrics dimensions for
-- the component BWM_TX_NODE
-------------------------------------------------------------------------------
insert into BWM.STG_TX_ND_MET
(
insert_dttm,
metric_id,
met_category,
met_name,
met_desc,
met_units,
min_exists,
max_exists,
avg_exists,
total_exists,
msrc_nm)
select
 current timestamp - current timezone as insert_dttm,
 mt.msmttyp_id as metric_id,
 'Not used' AS met_category,
 mt.msmttyp_nm as met_name,
 mt.msmttyp_ds as met_desc,
 mt.munit_cd as met_units ,
 value(min.min_exists,'N') as min_exists,
 value(max.max_exists,'N') as max_exists,
 value(avg.avg_exists,'N') as avg_exists,
 value(tot.tot_exists,'N') as total_exists,
 s.msrc_nm as msrc_nm
from
 twg.msmttyp mt left outer join session.temp_min_exists min
 on mt.msmttyp_id=min.msmttyp_id,
 twg.msmttyp mt2 left outer join session.temp_max_exists max
 on mt2.msmttyp_id=max.msmttyp_id,
 twg.msmttyp mt3 left outer join session.temp_avg_exists avg
 on mt3.msmttyp_id=avg.msmttyp_id,
 twg.msmttyp mt4 left outer join session.temp_tot_exists tot
 on mt4.msmttyp_id=tot.msmttyp_id,
 twg.msmtrul mr,
 twg.msrc s
where
 mt.msmttyp_id = mr.msmttyp_id and
 mt.msrc_cd IN ('BWM','MODEL1') and
 s.msrc_cd=mt.msrc_cd and
 mr.comptyp_cd = 'BWM_TX_NODE' and
 mt.msmttyp_id = mt2.msmttyp_id and
 mt.msmttyp_id = mt3.msmttyp_id and
 mt.msmttyp_id = mt4.msmttyp_id and
 not exists (select 1 from BWM.STG_TX_ND_MET m
        where
        m.metric_id = mt.msmttyp_id)
group by
 mt.msmttyp_id, mt.msmttyp_nm, mt.msmttyp_ds, mt.munit_cd,
 min_exists, avg_exists, tot_exists, max_exists, s.msrc_nm
;

--#endtag fixpack_5
