-------------------------------------------------------------------------------
--   OCO Source Materials
--
--   Licensed Materials - Property of IBM
--
--   5724-C02
--
--   (C) Copyright IBM Corp. 2003  All Rights Reserved.
--
--   US Government Users Restricted Rights - Use, duplication or
--   disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
-------------------------------------------------------------------------------
--    File Information: %W%
--    Revision: %I%
--    Date: %G% %U%
-------------------------------------------------------------------------------


-------------------------------------------------------------------------------
-- drop the staging table in twh_cdw for host
-------------------------------------------------------------------------------
--#IGNORE_ERROR          
DROP TABLE BWM.STAGE_HOST
;
-------------------------------------------------------------------------------
-- create the staging table in twh_cdw
-------------------------------------------------------------------------------
--#EXECUTE_AT_TARGET
CREATE TABLE BWM.STAGE_HOST (
  HOST_ID           DECIMAL(29,0) NOT NULL,
  HOST_NAME         VARCHAR(64),
  HOST_IP_ADDRESS   VARCHAR(15),
    PRIMARY KEY (HOST_ID)
);
--#EXECUTE_AT_TARGET
CREATE UNIQUE INDEX bwm.stg_host1 ON BWM.STAGE_HOST (HOST_NAME, HOST_IP_ADDRESS);


-------------------------------------------------------------------------------
-- drop the staging table in twh_cdw for applications
-------------------------------------------------------------------------------
--#IGNORE_ERROR          
DROP TABLE BWM.STAGE_APPLICATION
;
-------------------------------------------------------------------------------
-- create the staging table in twh_cdw
-------------------------------------------------------------------------------
--#EXECUTE_AT_TARGET
CREATE TABLE BWM.STAGE_APPLICATION (
  APPL_NAME         VARCHAR(128),
  APPL_ID           DECIMAL(29,0) NOT NULL,
    PRIMARY KEY (APPL_ID)
);
--#EXECUTE_AT_TARGET
CREATE UNIQUE INDEX bwm.stg_app1 ON BWM.STAGE_APPLICATION (APPL_NAME);

-------------------------------------------------------------------------------
-- drop the staging table in twh_cdw for users
-------------------------------------------------------------------------------
--#IGNORE_ERROR          
DROP TABLE BWM.STAGE_USER
;

-------------------------------------------------------------------------------
-- create the staging table in twh_cdw
-------------------------------------------------------------------------------
--#EXECUTE_AT_TARGET
CREATE TABLE BWM.STAGE_USER (
  USER_ID           DECIMAL(29,0) NOT NULL,
  USER_NAME         VARCHAR(128),
    PRIMARY KEY (USER_ID)
);
--#EXECUTE_AT_TARGET
CREATE UNIQUE INDEX bwm.stg_usr1 ON BWM.STAGE_USER (USER_NAME);

-------------------------------------------------------------------------------
-- drop the staging table in twh_cdw for transactions
-------------------------------------------------------------------------------
--#IGNORE_ERROR          
DROP TABLE BWM.STAGE_TRANSACTION
;

-------------------------------------------------------------------------------
-- create the staging table in twh_cdw
-------------------------------------------------------------------------------
--#EXECUTE_AT_TARGET
CREATE TABLE BWM.STAGE_TRANSACTION (
    TX_DESC         VARCHAR(128),
    TX_NAME         VARCHAR(4000),
    TX_ID           DECIMAL(29,0) NOT NULL,
    PRIMARY KEY (TX_ID)
);


-------------------------------------------------------------------------------
-- drop the staging table in twh_cdw for transactional node
-------------------------------------------------------------------------------
--#IGNORE_ERROR          
DROP TABLE BWM.STAGE_NODE
;

-------------------------------------------------------------------------------
-- create the staging table in twh_cdw
-------------------------------------------------------------------------------
--#EXECUTE_AT_TARGET
CREATE TABLE BWM.STAGE_NODE (
   NODE_ID       CHAR(24) FOR BIT DATA NOT NULL,
   APPL_ID       DECIMAL(29,0),
   TX_ID         DECIMAL(29,0),
   USER_ID       DECIMAL(29,0),
   HOST_ID       DECIMAL(29,0),
   NODE_SEQUENCE DECIMAL(29,0) NOT NULL,
    PRIMARY KEY (NODE_ID, NODE_SEQUENCE)
);
--#EXECUTE_AT_TARGET
CREATE INDEX bwm.stg_nd1 ON BWM.STAGE_NODE (APPL_ID); 
--#EXECUTE_AT_TARGET
CREATE INDEX bwm.stg_nd2 ON BWM.STAGE_NODE (TX_ID);
--#EXECUTE_AT_TARGET
CREATE INDEX bwm.stg_nd3 ON BWM.STAGE_NODE (USER_ID);
--#EXECUTE_AT_TARGET
CREATE INDEX bwm.stg_nd4 ON BWM.STAGE_NODE (HOST_ID);

-------------------------------------------------------------------------------
-- drop the staging table in twh_cdw for the relation map
-------------------------------------------------------------------------------
--#EXECUTE_AT_TARGET
--#IGNORE_ERROR          
DROP TABLE BWM.STAGE_RELATIONMAP
;
-------------------------------------------------------------------------------
-- create the staging table in twh_cdw
-------------------------------------------------------------------------------
--#EXECUTE_AT_TARGET
CREATE TABLE BWM.STAGE_RELATIONMAP (
  RELATIONMAP_ID            DECIMAL(29,0) NOT NULL,        
  MGMT_POLICY_OM_ID         DECIMAL(29,0) NOT NULL,
  PARENT_NODE_ID            CHAR(24) FOR BIT DATA,
  CURRENT_NODE_ID           CHAR(24) FOR BIT DATA NOT NULL,
  ROOT_NODE_ID              CHAR(24) FOR BIT DATA NOT NULL,
  RELATED_NODE_ID           CHAR(24) FOR BIT DATA,
    PRIMARY KEY (RELATIONMAP_ID)
);

--#EXECUTE_AT_TARGET
CREATE UNIQUE INDEX bwm.stg_rm1 ON BWM.STAGE_RELATIONMAP (ROOT_NODE_ID, PARENT_NODE_ID, CURRENT_NODE_ID, RELATED_NODE_ID, MGMT_POLICY_OM_ID);


-------------------------------------------------------------------------------
-- drop the staging table in twh_cdw for aggregate data
-------------------------------------------------------------------------------
--#IGNORE_ERROR          
DROP TABLE BWM.STAGE_AGGREG_DATA
;
-------------------------------------------------------------------------------
-- create the staging table in twh_cdw
-------------------------------------------------------------------------------
--#EXECUTE_AT_TARGET
CREATE TABLE BWM.STAGE_AGGREG_DATA (
    THRESH_VIOL_CNT     DECIMAL(29,0) NOT NULL,
    BAD_STATUS_CNT      DECIMAL(29,0) NOT NULL,
    ABORT_STATUS_CNT    DECIMAL(29,0) NOT NULL,
    COUNT               DECIMAL(29,0) NOT NULL,
    AVERAGE_VALUE       DECIMAL(29,0) NOT NULL,
    MAXIMUM_VALUE       DECIMAL(29,0) NOT NULL,
    MINIMUM_VALUE       DECIMAL(29,0) NOT NULL,
    AGGREGATE_ID        DECIMAL(29,0) NOT NULL,
    RELATIONMAP_ID      DECIMAL(29,0) NOT NULL,
    COLL_DATETIME       TIMESTAMP NOT NULL,
    PARTIAL             CHAR NOT NULL,
    PATT_TRANS_OM_ID    DECIMAL(29,0),
    COLL_TIME_SPAN      SMALLINT NOT NULL,
  PRIMARY KEY (AGGREGATE_ID)
    );
    
-------------------------------------------------------------------------------
-- drop the staging table in twh_cdw for management policy
-------------------------------------------------------------------------------
--#IGNORE_ERROR          
DROP TABLE BWM.STAGE_MGMTPOLICY
;

-------------------------------------------------------------------------------
-- create the staging table in twh_cdw
-------------------------------------------------------------------------------
--#EXECUTE_AT_TARGET
CREATE TABLE BWM.STAGE_MGMTPOLICY (
  NAME            VARCHAR(250),
  OBJECTVERSION   DECIMAL(29,0) NOT NULL,
  CREATOR         VARCHAR(250),
  CREATED         BIGINT,
  DELETED         BIGINT,
  DELETOR         VARCHAR(250),
  LASTUPDATED     BIGINT,
  UPDATOR         VARCHAR(250),
  DESCRIPTION     VARCHAR(250),
  UUID1           DECIMAL (29,0) NOT NULL,
  ISDELETE        SMALLINT NOT NULL,
  TYPE1           VARCHAR(250),
  STATE1          VARCHAR(250),
  EDGEPOLICY_UUID VARCHAR(250),
  SCHEDULE_UUID   DECIMAL(29,0),
  ENDPOINTGROUP_UUID DECIMAL(29,0),
  PRIMARY KEY (UUID1)
);



-------------------------------------------------------------------------------
-- drop the staging table in twh_cdw for pattern transaction
-------------------------------------------------------------------------------
--#IGNORE_ERROR          
DROP TABLE BWM.STAGE_PATTERN
;

-------------------------------------------------------------------------------
-- create the staging table in twh_cdw
-------------------------------------------------------------------------------
--#EXECUTE_AT_TARGET
CREATE TABLE BWM.STAGE_PATTERN (
  UUID1            DECIMAL(29,0) NOT NULL,
  PRIMARY KEY (UUID1)
);

-------------------------------------------------------------------------------
-- drop the staging table in twh_cdw for Threshold
-------------------------------------------------------------------------------
--#IGNORE_ERROR          
DROP TABLE BWM.STAGE_THRESHOLD
;

-------------------------------------------------------------------------------
-- create the staging table in twh_cdw
-------------------------------------------------------------------------------
--#EXECUTE_AT_TARGET
CREATE TABLE BWM.STAGE_THRESHOLD (
 UUID1 DECIMAL (29,0) NOT NULL,
 PATTERN_ID DECIMAL(29,0),
 THRESHOLDVALUE DECIMAL(29,0),
 TR_UUID DECIMAL(29,0),
 PRIMARY KEY (UUID1)
);
--#EXECUTE_AT_TARGET
CREATE UNIQUE INDEX bwm.stg_thr1 ON BWM.STAGE_THRESHOLD (PATTERN_ID, TR_UUID);

-------------------------------------------------------------------------------
-- drop the staging table in twh_cdw for Trigger Response
-------------------------------------------------------------------------------
--#IGNORE_ERROR          
DROP TABLE BWM.STAGE_TR
;

-------------------------------------------------------------------------------
-- create the staging table in twh_cdw
-------------------------------------------------------------------------------
--#EXECUTE_AT_TARGET
CREATE TABLE BWM.STAGE_TR (
 UUID1 DECIMAL(29,0) NOT NULL,
 MGMT_POLICY_ID DECIMAL(29,0),
 RESPONSELEVEL DECIMAL(29,0),
 PRIMARY KEY (UUID1)
);
--#EXECUTE_AT_TARGET
CREATE INDEX bwm.stg_tr1 ON BWM.STAGE_TR (MGMT_POLICY_ID);



